@@ -392,9 +392,9 @@ LockStruct  LockProcs[] =
 	 50000, 35, 50, 1, 64, 1.0, "",
 	 "Shows slipping blits", 0, NULL, NULL},
 #ifdef HAVE_CXX
-	{"solitare",
+	{"solitaire",
 	 2000000, 1, 1, 1, 64, 1.0, "",
-	 "Shows Klondike's game of solitare", 0, NULL, "#ifdef HAVE_CXX"},
+	 "Shows Klondike's game of solitaire", 0, NULL, "#ifdef HAVE_CXX"},
 #endif
 	{"space",
 	 10000, 100, 1, 15, 64, 1.0, "",
