@@ -4,66 +4,66 @@
 &search;
 
 sub search {
-    local ($row, $col, $NOTUSED, $x, $y);
+    local ($col, $row, $NOTUSED, $x, $y);
     local (@array);
 
     $HALFMAX = 64; # really 32 but being safe
     $MAXCOL = $MINCOL = $MAXROW = $MINROW = $HALFMAX;
     $NOTUSED = -127;
-    $row = $col = $NOTUSED;
+    $col = $row = $NOTUSED;
     $number = 0;
     while (<>) {
         if (!($_ =~ /^#/)) {
-            @chars = split(//);
+	    @chars = split(//);
 	    $number = 0;
 	    $col = $NOTUSED;
 	    $negative = 1;
-            foreach $c (@chars) {
-                if ($c =~ /[-]/) {
+	    foreach $c (@chars) {
+		if ($c =~ /[-]/) {
 		    $negative = -1;
 		} elsif ($c =~ /[0123456789]/) {
 		    $number = $number * 10 + ($c - '0');
 		} elsif ($c =~ /[,]/) { # Last number does not have a ","
 		    if ($col > $NOTUSED) {
-		        $row = $number * $negative;
-                        $col = $col + $HALFMAX;
+			$row = $number * $negative;
+			$col = $col + $HALFMAX;
 			$row = $row + $HALFMAX;
-                        $array{$col, $row} = 1;
-		        if ($col > $MAXCOL) {
+			$array{$col, $row} = 1;
+			if ($col > $MAXCOL) {
 			    $MAXCOL = $col;
-		        } elsif ($col < $MINCOL) {
+			} elsif ($col < $MINCOL) {
 			    $MINCOL = $col;
-                        }
-		        if ($row > $MAXROW) {
+			}
+			if ($row > $MAXROW) {
  			    $MAXROW = $row;
-		        } elsif ($row < $MINROW) {
+			} elsif ($row < $MINROW) {
 			    $MINROW = $row;
-                        }
-	                $col = $NOTUSED;
+			}
+			$col = $NOTUSED;
 		    } else {
 			$col = $number * $negative;
-                    }
+		    }
 		    $number = 0;
 	    	    $negative = 1;
 		} elsif ($c =~ /[{}\/]/) { # Last number does not have a ","
-	            $col = $NOTUSED;
+		    $col = $NOTUSED;
 		    $number = 0;
 	    	    $negative = 1;
-                }
-            }
-        }
+		}
+	    }
+	}
     }
     $x=$MAXCOL - $MINCOL + 1;
     $y=$MAXROW - $MINROW + 1;
     print "#x=$x, y=$y\n";
     for ($j = $MINROW; $j <= $MAXROW; $j++) {
-        for ($i = $MINCOL; $i <= $MAXCOL; $i++) {
-            if ($array{$i, $j}) {
-                print "*";
+	for ($i = $MINCOL; $i <= $MAXCOL; $i++) {
+	    if ($array{$i, $j}) {
+		print "*";
  	    } else {
-                print ".";
-            }
-        }
-        print "\n";
+		print ".";
+	    }
+	}
+	print "\n";
     }
 }
