@@ -747,7 +747,7 @@ sierpinski\
 sierpinski3d\
 skewb\
 slip\
-solitare\
+solitaire\
 space\
 sphere\
 spiral\
