@@ -2,7 +2,7 @@
 /* crystal --- polygons moving according to plane group rules */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)crystal.c	5.08 2003/04/28 xlockmore";
+static const char sccsid[] = "@(#)crystal.c	5.24 2007/01/18 xlockmore";
 
 #endif
 
@@ -32,15 +32,14 @@ static const char sccsid[] = "@(#)crystal.c	5.08 2003/04/28 xlockmore";
  *   square groups 3 through 11 where the angle gamma is 90 degrees
  *   hexagonal groups 12 through 17 where the angle gamma is 120 degrees
  *
- * TODO:
+ * Revision History:
+ * 18-Jan-2007: Added vertical option.
  *   Crystals (particularly the parallelagram ones) favor the lower
  *     right corner in small windows.
- *   Parallelagrams always look like this:
+ *   Parallelagrams always look like this without -vertical:
  *      __      __                   /|
  *     /_/  or  \_\  but never like  |/  (coded this way because screen is
  *     usually longer horizontally).
- *
- * Revision History:
  * 28-Apr-2003: Changed so it works in a 64x64 window
  * 01-Nov-2000: Allocation checks
  * 03-Dec-1998: Random inversion of y-axis included to simulate hexagonal
@@ -110,10 +109,11 @@ static const char sccsid[] = "@(#)crystal.c	5.08 2003/04/28 xlockmore";
 #define DEF_CENTRE "False"
 #define DEF_MAXSIZE "False"
 #define DEF_CYCLE "True"
+#define DEF_VERTICAL "False"
 
 static int  nx, ny;
 
-static Bool unit_cell, grid_cell, centre, maxsize, cycle_p;
+static Bool unit_cell, grid_cell, centre, maxsize, cycle_p, vertical;
 
 static XrmOptionDescRec opts[] =
 {
@@ -128,7 +128,9 @@ static XrmOptionDescRec opts[] =
 	{(char *) "-grid", (char *) ".crystal.grid", XrmoptionNoArg, (caddr_t) "on"},
 	{(char *) "+grid", (char *) ".crystal.grid", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-cycle", (char *) ".crystal.cycle", XrmoptionNoArg, (caddr_t) "on"},
-	{(char *) "+cycle", (char *) ".crystal.cycle", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "+cycle", (char *) ".crystal.cycle", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-vertical", (char *) ".crystal.vertical", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+vertical", (char *) ".crystal.vertical", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
@@ -139,7 +141,8 @@ static argtype vars[] =
 	{(void *) & maxsize, (char *) "maxsize", (char *) "Maxsize", (char *) DEF_MAXSIZE, t_Bool},
 	{(void *) & unit_cell, (char *) "cell", (char *) "Cell", (char *) DEF_CELL, t_Bool},
 	{(void *) & grid_cell, (char *) "grid", (char *) "Grid", (char *) DEF_GRID, t_Bool},
-	{(void *) & cycle_p, (char *) "cycle", (char *) "Cycle", (char *) DEF_CYCLE, t_Bool}
+	{(void *) & cycle_p, (char *) "cycle", (char *) "Cycle", (char *) DEF_CYCLE, t_Bool},
+	{(void *) & vertical, (char *) "vertical", (char *) "Vertical", (char *) DEF_VERTICAL, t_Bool}
 };
 static OptionStruct desc[] =
 {
@@ -149,7 +152,8 @@ static OptionStruct desc[] =
 	{(char *) "-/+maxsize", (char *) "turn on/off use of maximum part of screen"},
 	{(char *) "-/+cell", (char *) "turn on/off drawing of unit cell"},
 	{(char *) "-/+grid", (char *) "turn on/off drawing of grid of unit cells (if -cell is on)"},
-	{(char *) "-/+cycle", (char *) "turn on/off colour cycling"}
+	{(char *) "-/+cycle", (char *) "turn on/off colour cycling"},
+	{(char *) "-/+vertical", (char *) "change orientation"}
 };
 
 ModeSpecOpt crystal_opts =
@@ -265,7 +269,7 @@ typedef struct {
 } crystalatom;
 
 typedef struct {
-	Bool        painted;
+	Bool        painted, vertical;
 	int         win_width, win_height, num_atom;
 	int         planegroup, a, b, offset_w, offset_h, nx, ny;
 	float       gamma;
@@ -285,13 +289,13 @@ static crystalstruct *crystals = (crystalstruct *) NULL;
 
 static void
 trans_coor(XPoint * xyp, XPoint * new_xyp, int num_points,
-	   float gamma )
+	   float gamma)
 {
 	int         i;
 
 	for (i = 0; i <= num_points; i++) {
-		new_xyp[i].x = xyp[i].x +
-			(int) (xyp[i].y * sin((gamma - 90.0) * PI_RAD));
+		new_xyp[i].x = xyp[i].x + (int) (xyp[i].y *
+			sin((gamma - 90.0) * PI_RAD));
 		new_xyp[i].y = (int) (xyp[i].y / cos((gamma - 90.0) * PI_RAD));
 	}
 }
@@ -299,16 +303,26 @@ trans_coor(XPoint * xyp, XPoint * new_xyp, int num_points,
 static void
 trans_coor_back(XPoint * xyp, XPoint * new_xyp,
 		int num_points, float gamma, int offset_w, int offset_h ,
-		int winheight , int invert )
+		int winheight , int invert, Bool new_vertical)
 {
 	int         i;
 
 	for (i = 0; i <= num_points; i++) {
-		new_xyp[i].y = (int) (xyp[i].y * cos((gamma - 90) * PI_RAD)) +
-			offset_h;
-		new_xyp[i].x = xyp[i].x - (int) (xyp[i].y * sin((gamma - 90.0)
-						       * PI_RAD)) + offset_w;
-	   if ( invert ) new_xyp[i].y = winheight - new_xyp[i].y;
+		if (new_vertical) {
+			new_xyp[i].x = (int) (xyp[i].y *
+				cos((gamma - 90) * PI_RAD)) + offset_h;
+			new_xyp[i].y = xyp[i].x - (int) (xyp[i].y *
+				sin((gamma - 90.0) * PI_RAD)) + offset_w;
+			if (invert)
+				new_xyp[i].x = winheight - new_xyp[i].x;
+		} else {
+			new_xyp[i].y = (int) (xyp[i].y *
+				cos((gamma - 90) * PI_RAD)) + offset_h;
+			new_xyp[i].x = xyp[i].x - (int) (xyp[i].y *
+				sin((gamma - 90.0) * PI_RAD)) + offset_w;
+			if (invert)
+				new_xyp[i].y = winheight - new_xyp[i].y;
+		}
 	}
 }
 
@@ -477,7 +491,8 @@ crystal_drawatom(ModeInfo * mi, crystalatom * atom0)
 						cryst->gamma, cryst->offset_w,
 						cryst->offset_h ,
 						cryst->win_height,
-						cryst->invert);
+						cryst->invert,
+						cryst->vertical);
 				XFillPolygon(display, window, cryst->gc, new_xy,
 				  atom0->num_point, Convex, CoordModeOrigin);
 			}
@@ -497,9 +512,10 @@ crystal_drawatom(ModeInfo * mi, crystalatom * atom0)
 					trans_coor_back(xy_1, new_xy, atom0->num_point,
 							cryst->gamma,
 							cryst->offset_w,
-							cryst->offset_h ,
-							cryst->win_height ,
-							cryst->invert);
+							cryst->offset_h,
+							cryst->win_height,
+							cryst->invert,
+							cryst->vertical);
 					XFillPolygon(display, window, cryst->gc,
 						     new_xy,
 						     atom0->num_point, Convex,
@@ -532,7 +548,8 @@ crystal_drawatom(ModeInfo * mi, crystalatom * atom0)
 							cryst->offset_w,
 							cryst->offset_h ,
 							cryst->win_height,
-							cryst->invert);
+							cryst->invert,
+							cryst->vertical);
 					XFillPolygon(display, window, cryst->gc,
 						     new_xy,
 						     atom0->num_point, Convex,
@@ -558,7 +575,8 @@ crystal_drawatom(ModeInfo * mi, crystalatom * atom0)
 								cryst->offset_w,
 								cryst->offset_h ,
 								cryst->win_height,
-								cryst->invert);
+								cryst->invert,
+								cryst->vertical);
 						XFillPolygon(display, window,
 							     cryst->gc,
 						    new_xy, atom0->num_point,
@@ -603,6 +621,21 @@ free_crystal(Display *display, crystalstruct *cryst)
 	}
 }
 
+
+static void
+DrawLine(Display *display, Window window, crystalstruct *cryst,
+		int x_1, int y_1, int x_2, int y_2)
+{
+
+	if (cryst->vertical) {
+		XDrawLine(display, window, cryst->gc,
+			y_1, x_1, y_2, x_2);
+	} else {
+		XDrawLine(display, window, cryst->gc,
+			x_1, y_1, x_2, y_2);
+	}
+}
+
 #ifndef STANDALONE
 extern char *background;
 extern char *foreground;
@@ -675,23 +708,26 @@ init_crystal(ModeInfo * mi)
 /*Set up crystal data */
 	cryst->direction = (LRAND() & 1) ? 1 : -1;
 	if (MI_IS_FULLRANDOM(mi)) {
-		if (LRAND() & 1)
-			cryst->unit_cell = True;
-		else
-			cryst->unit_cell = False;
-	} else
+		cryst->unit_cell = (Bool) (LRAND() & 1);
+		cryst->vertical = (Bool) (LRAND() & 1);
+	} else {
 		cryst->unit_cell = unit_cell;
+		cryst->vertical = vertical;
+	}
 	if (cryst->unit_cell) {
-		if (MI_IS_FULLRANDOM(mi)) {
-			if (LRAND() & 1)
-				cryst->grid_cell = True;
-			else
-				cryst->grid_cell = False;
-		} else
+		if (MI_IS_FULLRANDOM(mi))
+			cryst->grid_cell = (Bool) (LRAND() & 1);
+		else
 			cryst->grid_cell = grid_cell;
+	
+	}
+	if (cryst->vertical) {
+		cryst->win_height = MAX(MI_WIDTH(mi) + 1, MIN_CELL);
+		cryst->win_width = MAX(MI_HEIGHT(mi) + 1, MIN_CELL);
+	} else {
+		cryst->win_width = MAX(MI_WIDTH(mi) + 1, MIN_CELL);
+		cryst->win_height = MAX(MI_HEIGHT(mi) + 1, MIN_CELL);
 	}
-	cryst->win_width = MAX(MI_WIDTH(mi) + 1, MIN_CELL);
-	cryst->win_height = MAX(MI_HEIGHT(mi) + 1, MIN_CELL);
 	cell_min = MIN(cryst->win_width / 2 + 1, MIN_CELL);
 	cell_min = MIN(cell_min, cryst->win_height / 2 + 1);
 	cryst->planegroup = NRAND(17);
@@ -771,8 +807,9 @@ init_crystal(ModeInfo * mi)
 		cryst->offset_w = -1;
 		while (cryst->offset_w < 4 || (int) (cryst->offset_w - cryst->b *
 				    sin((cryst->gamma - 90) * PI_RAD)) < 4) {
-			cryst->b = NRAND((int) (cryst->win_height / (cos((cryst->gamma - 90) *
-					    PI_RAD))) - cell_min) + cell_min;
+			cryst->b = NRAND((int) (cryst->win_height /
+				(cos((cryst->gamma - 90) *
+				PI_RAD))) - cell_min) + cell_min;
 			if (cryst->planegroup > 8)
 				cryst->a = cryst->b;
 			else
@@ -827,7 +864,7 @@ init_crystal(ModeInfo * mi)
 		     y_coor1 = y_coor2 = cryst->win_height - cryst->offset_h;
 		   else
 		     y_coor1 = y_coor2 = cryst->offset_h;
-			XDrawLine(display, window, cryst->gc, cryst->offset_w,
+			DrawLine(display, window, cryst, cryst->offset_w,
 				  y_coor1, cryst->offset_w + cryst->nx * cryst->a,
 				  y_coor2);
 		   if ( cryst->invert )
@@ -845,7 +882,7 @@ init_crystal(ModeInfo * mi)
 					 cos((cryst->gamma - 90) * PI_RAD)) +
 			  cryst->offset_h;
 		     }
-			XDrawLine(display, window, cryst->gc, cryst->offset_w,
+			DrawLine(display, window, cryst, cryst->offset_w,
 				  y_coor1, (int) (cryst->offset_w - cryst->ny * cryst->b *
 					  sin((cryst->gamma - 90) * PI_RAD)),
 				  y_coor2);
@@ -868,7 +905,7 @@ init_crystal(ModeInfo * mi)
 			y_coor2 = (int) (iny * cryst->b * cos((cryst->gamma - 90) * PI_RAD)) +
 					  cryst->offset_h;
 		     }
-				XDrawLine(display, window, cryst->gc,
+				DrawLine(display, window, cryst,
 					  (int) (cryst->offset_w +
 				     inx * cryst->a - (int) (iny * cryst->b *
 					 sin((cryst->gamma - 90) * PI_RAD))),
@@ -894,7 +931,7 @@ init_crystal(ModeInfo * mi)
 						    PI_RAD)) + cryst->offset_h;
 				y_coor2 =cryst->offset_h;
 			     }
-				XDrawLine(display, window, cryst->gc,
+				DrawLine(display, window, cryst,
 					  (int) (cryst->offset_w +
 				     inx * cryst->a - (int) (iny * cryst->b *
 					 sin((cryst->gamma - 90) * PI_RAD))),
@@ -931,22 +968,22 @@ init_crystal(ModeInfo * mi)
 						      PI_RAD)) +
 			  cryst->offset_h;
 		     }
-			XDrawLine(display, window, cryst->gc,
+			DrawLine(display, window, cryst,
 				  cryst->offset_w + inx * cryst->a - (int) (iny * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
 				  y_coor1,
 				  cryst->offset_w + (inx + 1) * cryst->a - (int) (iny * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
 				  y_coor1);
-			XDrawLine(display, window, cryst->gc,
+			DrawLine(display, window, cryst,
 				  cryst->offset_w + inx * cryst->a - (int) (iny * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
 				  y_coor1,
 				  cryst->offset_w + inx * cryst->a - (int) ((iny + 1) * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
 				  y_coor2);
-			XDrawLine(display, window, cryst->gc,
+			DrawLine(display, window, cryst,
 				  cryst->offset_w + (inx + 1) * cryst->a - (int) (iny * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
 				  y_coor1,
 				  cryst->offset_w + (inx + 1) * cryst->a - (int) ((iny + 1) * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
 				  y_coor2);
-			XDrawLine(display, window, cryst->gc,
+			DrawLine(display, window, cryst,
 				  cryst->offset_w + inx * cryst->a - (int) ((iny + 1) * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
 				  y_coor2,
 				  cryst->offset_w + (inx + 1) * cryst->a - (int) ((iny + 1) * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
@@ -1168,7 +1205,7 @@ refresh_crystal(ModeInfo * mi)
 		     y_coor1 = y_coor2 = cryst->win_height - cryst->offset_h;
 		   else
 		     y_coor1 = y_coor2 = cryst->offset_h;
-			XDrawLine(display, window, cryst->gc, cryst->offset_w,
+			DrawLine(display, window, cryst, cryst->offset_w,
 				  y_coor1, cryst->offset_w + cryst->nx * cryst->a,
 				  y_coor2);
 		   if ( cryst->invert )
@@ -1186,7 +1223,7 @@ refresh_crystal(ModeInfo * mi)
 					 cos((cryst->gamma - 90) * PI_RAD)) +
 			  cryst->offset_h;
 		     }
-			XDrawLine(display, window, cryst->gc, cryst->offset_w,
+			DrawLine(display, window, cryst, cryst->offset_w,
 				  y_coor1, (int) (cryst->offset_w - cryst->ny * cryst->b *
 					  sin((cryst->gamma - 90) * PI_RAD)),
 				  y_coor2);
@@ -1209,7 +1246,7 @@ refresh_crystal(ModeInfo * mi)
 			y_coor2 = (int) (iny * cryst->b * cos((cryst->gamma - 90) * PI_RAD)) +
 					  cryst->offset_h;
 		     }
-				XDrawLine(display, window, cryst->gc,
+				DrawLine(display, window, cryst,
 					  (int) (cryst->offset_w +
 				     inx * cryst->a - (int) (iny * cryst->b *
 					 sin((cryst->gamma - 90) * PI_RAD))),
@@ -1235,7 +1272,7 @@ refresh_crystal(ModeInfo * mi)
 						    PI_RAD)) + cryst->offset_h;
 				y_coor2 =cryst->offset_h;
 			     }
-				XDrawLine(display, window, cryst->gc,
+				DrawLine(display, window, cryst,
 					  (int) (cryst->offset_w +
 				     inx * cryst->a - (int) (iny * cryst->b *
 					 sin((cryst->gamma - 90) * PI_RAD))),
@@ -1272,22 +1309,22 @@ refresh_crystal(ModeInfo * mi)
 						      PI_RAD)) +
 			  cryst->offset_h;
 		     }
-			XDrawLine(display, window, cryst->gc,
+			DrawLine(display, window, cryst,
 				  cryst->offset_w + inx * cryst->a - (int) (iny * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
 				  y_coor1,
 				  cryst->offset_w + (inx + 1) * cryst->a - (int) (iny * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
 				  y_coor1);
-			XDrawLine(display, window, cryst->gc,
+			DrawLine(display, window, cryst,
 				  cryst->offset_w + inx * cryst->a - (int) (iny * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
 				  y_coor1,
 				  cryst->offset_w + inx * cryst->a - (int) ((iny + 1) * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
 				  y_coor2);
-			XDrawLine(display, window, cryst->gc,
+			DrawLine(display, window, cryst,
 				  cryst->offset_w + (inx + 1) * cryst->a - (int) (iny * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
 				  y_coor1,
 				  cryst->offset_w + (inx + 1) * cryst->a - (int) ((iny + 1) * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
 				  y_coor2);
-			XDrawLine(display, window, cryst->gc,
+			DrawLine(display, window, cryst,
 				  cryst->offset_w + inx * cryst->a - (int) ((iny + 1) * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
 				  y_coor2,
 				  cryst->offset_w + (inx + 1) * cryst->a - (int) ((iny + 1) * cryst->b * sin((cryst->gamma - 90) * PI_RAD)),
