@@ -144,8 +144,8 @@ typedef struct {
 	GC          stippledGC;
 	Pixmap      pixmaps[NUMSTIPPLES - 1];
 	union {
-		XPoint      hexagon[6];
-		XPoint      triangle[2][3];
+		XPoint      hexagon[7];
+		XPoint      triangle[2][4];
 	} shape;
 } demonstruct;
 
@@ -161,13 +161,15 @@ static void
 drawcell(ModeInfo * mi, int col, int row, unsigned char state)
 {
 	demonstruct *dp = &demons[MI_SCREEN(mi)];
+	Display *display = MI_DISPLAY(mi);
+	Window window = MI_WINDOW(mi);
 	GC          gc;
 
 	if (!state) {
-		XSetForeground(MI_DISPLAY(mi), MI_GC(mi), MI_BLACK_PIXEL(mi));
+		XSetForeground(display, MI_GC(mi), MI_BLACK_PIXEL(mi));
 		gc = MI_GC(mi);
 	} else if (MI_NPIXELS(mi) >= NUMSTIPPLES) {
-		XSetForeground(MI_DISPLAY(mi), MI_GC(mi),
+		XSetForeground(display, MI_GC(mi),
 			MI_PIXEL(mi, (((int) state - 1) * MI_NPIXELS(mi) /
 			(dp->states - 1)) % MI_NPIXELS(mi)));
 		gc = MI_GC(mi);
@@ -177,7 +179,7 @@ drawcell(ModeInfo * mi, int col, int row, unsigned char state)
 		gcv.stipple = dp->pixmaps[(state - 1) % (NUMSTIPPLES - 1)];
 		gcv.foreground = MI_WHITE_PIXEL(mi);
 		gcv.background = MI_BLACK_PIXEL(mi);
-		XChangeGC(MI_DISPLAY(mi), dp->stippledGC,
+		XChangeGC(display, dp->stippledGC,
 			  GCStipple | GCForeground | GCBackground, &gcv);
 		gc = dp->stippledGC;
 	}
@@ -192,15 +194,15 @@ drawcell(ModeInfo * mi, int col, int row, unsigned char state)
 			dp->shape.hexagon[0].x = dp->yb + crow * dp->ys;
 		}
 		if (dp->xs == 1 && dp->ys == 1)
-			XDrawPoint(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+			XDrawPoint(display, window, gc,
 				dp->shape.hexagon[0].x,
 				dp->shape.hexagon[0].y);
 		else
-			XFillPolygon(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+			XFillPolygon(display, window, gc,
 				dp->shape.hexagon, 6,
 				Convex, CoordModePrevious);
 	} else if (dp->neighbors == 4 || dp->neighbors == 8) {
-		XFillRectangle(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+		XFillRectangle(display, window, gc,
 			dp->xb + dp->xs * col, dp->yb + dp->ys * row,
 			dp->xs - (dp->xs > 3), dp->ys - (dp->ys > 3));
 	} else {		/* TRI */
@@ -227,14 +229,17 @@ drawcell(ModeInfo * mi, int col, int row, unsigned char state)
 					(dp->xs / 2  - 1) * ((orient) ? 1 : -1);
 		}
 		if (small)
-			XDrawPoint(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+			XDrawPoint(display, window, gc,
 				dp->shape.triangle[orient][0].x,
 				dp->shape.triangle[orient][0].y);
 		else {
-			XFillPolygon(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+			XFillPolygon(display, window, gc,
 				dp->shape.triangle[orient], 3,
 				Convex, CoordModePrevious);
-
+			XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+			XDrawLines(display, window, gc,
+				dp->shape.triangle[orient], 4,
+				CoordModePrevious);
 		}
 	}
 }
@@ -344,15 +349,17 @@ static Bool
 draw_state(ModeInfo * mi, int state)
 {
 	demonstruct *dp = &demons[MI_SCREEN(mi)];
+	Display *display = MI_DISPLAY(mi);
+	Window window = MI_WINDOW(mi);
 	GC          gc;
 	XRectangle *rects;
 	CellList   *current;
 
 	if (!state) {
-		XSetForeground(MI_DISPLAY(mi), MI_GC(mi), MI_BLACK_PIXEL(mi));
+		XSetForeground(display, MI_GC(mi), MI_BLACK_PIXEL(mi));
 		gc = MI_GC(mi);
 	} else if (MI_NPIXELS(mi) >= NUMSTIPPLES) {
-		XSetForeground(MI_DISPLAY(mi), MI_GC(mi),
+		XSetForeground(display, MI_GC(mi),
 			   MI_PIXEL(mi, (((int) state - 1) * MI_NPIXELS(mi) /
 					 (dp->states - 1)) % MI_NPIXELS(mi)));
 		gc = MI_GC(mi);
@@ -362,7 +369,7 @@ draw_state(ModeInfo * mi, int state)
 		gcv.stipple = dp->pixmaps[(state - 1) % (NUMSTIPPLES - 1)];
 		gcv.foreground = MI_WHITE_PIXEL(mi);
 		gcv.background = MI_BLACK_PIXEL(mi);
-		XChangeGC(MI_DISPLAY(mi), dp->stippledGC,
+		XChangeGC(display, dp->stippledGC,
 			  GCStipple | GCForeground | GCBackground, &gcv);
 		gc = dp->stippledGC;
 	}
@@ -382,11 +389,11 @@ draw_state(ModeInfo * mi, int state)
 				dp->shape.hexagon[0].x = dp->yb + crow * dp->ys;
 			}
 			if (dp->xs == 1 && dp->ys == 1)
-				XDrawPoint(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+				XDrawPoint(display, window, gc,
 					dp->shape.hexagon[0].x,
 					dp->shape.hexagon[0].y);
 			else
-				XFillPolygon(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+				XFillPolygon(display, window, gc,
 					dp->shape.hexagon, 6,
 					Convex, CoordModePrevious);
 			current = current->next;
@@ -410,10 +417,12 @@ draw_state(ModeInfo * mi, int state)
 			ncells++;
 		}
 		/* Finally get to draw */
-		XFillRectangles(MI_DISPLAY(mi), MI_WINDOW(mi), gc, rects, ncells);
+		XFillRectangles(display, window, gc, rects, ncells);
 		/* Free up rects list and the appropriate part of the cellList */
 		free(rects);
 	} else {		/* TRI */
+		XGCValues values;
+		GC borderGC = XCreateGC(display, window, 0, &values);
 		Bool small = (dp->xs <= 3 || dp->ys <= 3);
 
 		current = dp->cellList[state];
@@ -443,19 +452,27 @@ draw_state(ModeInfo * mi, int state)
 						(dp->xs / 2  - 1) * ((orient) ? 1 : -1);
 			}
 			if (small)
-				XDrawPoint(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+				XDrawPoint(display, window, gc,
 					dp->shape.triangle[orient][0].x,
 					dp->shape.triangle[orient][0].y);
 			else {
-				XFillPolygon(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+				XFillPolygon(display, window, gc,
 					dp->shape.triangle[orient], 3,
 					Convex, CoordModePrevious);
+				if (borderGC != None) {
+					XSetForeground(display, borderGC, MI_BLACK_PIXEL(mi));
+					XDrawLines(display, window, borderGC,
+						dp->shape.triangle[orient], 4,
+						CoordModePrevious);
+				}
 			}
 			current = current->next;
 		}
+		if (borderGC != None)
+			XFreeGC(display, borderGC);
 	}
 	free_state(dp, state);
-	XFlush(MI_DISPLAY(mi));
+	XFlush(display);
 	return True;
 }
 
