@@ -151,7 +151,7 @@ ModStruct   dilemma_description =
 #define MINGRIDSIZE 16
 #define MINSIZE 10
 #define FACTOR 10
-#define NEIGHBORKINDS 6
+#define NEIGHBORKINDS 2
 #define REDRAWSTEP 2000		/* How many cells to draw per cycle */
 #define ROUND_FLOAT(x,a) ((float) ((int) ((x) / (a) + 0.5)) * (a))
 
@@ -189,14 +189,14 @@ typedef struct {
 	int         width, height;
 	int         neighbors;
 	union {
-		XPoint      hexagon[6];
-		XPoint      triangle[2][3];
+		XPoint      hexagon[7];
+		XPoint      triangle[2][4];
 	} shape;
 } dilemmastruct;
 
 static char plots[NEIGHBORKINDS] =
 {
-	3, 4, 6, 8, 9, 12	/* Neighborhoods */
+	4, 8	/* Neighborhoods: 3, 6, 9 & 12 do not really work */
 };
 
 static dilemmastruct *dilemmas = (dilemmastruct *) NULL;
@@ -335,11 +335,15 @@ drawcell(ModeInfo * mi, int col, int row, unsigned long color, int bitmap,
 				dp->shape.triangle[orient][0].x,
 				dp->shape.triangle[orient][0].y);
 		else {
-			if (bitmap == BITMAPS - 1)
+			if (bitmap == BITMAPS - 1) {
 				XFillPolygon(display, window, gc,
 					dp->shape.triangle[orient], 3,
 					Convex, CoordModePrevious);
-			else {
+				XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+				XDrawLines(display, window, gc,
+					dp->shape.triangle[orient], 4,
+					CoordModePrevious);
+			} else {
 				if (firstChange) {
 					XSetForeground(display, gc,
 						MI_BLACK_PIXEL(mi));
