@@ -411,6 +411,7 @@ mat_make_rotation_around_y(struct matrix *m, float ang)
 	m->m31 = s; m->m33 = c;
 }
 
+#if 0
 static void
 mat_make_rotation_around_z(struct matrix *m, float ang)
 {
@@ -424,6 +425,7 @@ mat_make_rotation_around_z(struct matrix *m, float ang)
 	m->m11 = c; m->m12 = -s;
 	m->m21 = s; m->m22 = c;
 }
+#endif
 
 static void
 mat_make_translation(struct matrix *m, float x, float y, float z)
@@ -462,11 +464,13 @@ mat_mul_copy(struct matrix *r, struct matrix *a, struct matrix *b)
 	r->m31 = l31; r->m32 = l32; r->m33 = l33; r->m34 = l34;
 }
 
+#if 0
 static void
 mat_mul(struct matrix *a, struct matrix *b)
 {
 	mat_mul_copy(a, a, b);
 }
+#endif
 
 static void
 mat_transform_copy(struct vector *r, struct matrix *m,
@@ -545,9 +549,9 @@ init_edge(fzort_ctx *ctx, struct edge *edge,
 		y_max = ctx->clip.y_max;
 
 	if (y_max <= edge->sy) {
-		edge->lines = 0;
+		edge->lines = edge->dxdy = edge->sx = 0;
 	} else {
-		edge->lines = y_max - edge->sy;
+		edge->lines = (int) (y_max - edge->sy);
 		edge->dxdy = fp_div(edge->dx, edge->dy);
 		edge->sx = INT_TO_FP(v0->x_scr) + edge->adjy*edge->dxdy;
 	} 
@@ -638,13 +642,13 @@ render_process_mesh(fzort_ctx *ctx, struct matrix *m)
 		vec_normalize(&normal);
 
 		pv->u_txt = FLOAT_TO_FP((TEXTURE_SIZE/2) +
-		  (TEXTURE_SIZE/2)*normal.y + .5);
+		  (TEXTURE_SIZE/2)*normal.y + 0.5);
 		pv->v_txt = FLOAT_TO_FP((TEXTURE_SIZE/2) +
-		  (TEXTURE_SIZE/2)*normal.x + .5);
+		  (TEXTURE_SIZE/2)*normal.x + 0.5);
 	
 		w = ctx->lx/pv->p.z;
-		pv->x_scr = ctx->cx + w*pv->p.x + .5;
-		pv->y_scr = ctx->cy + w*pv->p.y + .5;
+		pv->x_scr = (int) (ctx->cx + w*pv->p.x + 0.5);
+		pv->y_scr = (int) (ctx->cy + w*pv->p.y + 0.5);
 
 		if (pv->x_scr < x_scr_min)
 			x_scr_min = pv->x_scr; 
@@ -755,7 +759,7 @@ render_process_mesh(fzort_ctx *ctx, struct matrix *m)
 		z_scale = 255.f/(z_max - z_min);
 	
 		for (i = 0; i < npoly; i++)
-			ctx->order_in[i].zi = z_scale*(ctx->order_in[i].z - z_min);
+			ctx->order_in[i].zi = (unsigned int) (z_scale*(ctx->order_in[i].z - z_min));
 	
 		radix_sort(ctx->order_out, ctx->order_in, 0, npoly);
 	
@@ -820,7 +824,8 @@ calc_mesh_vertices(struct mesh *mesh, int density, float radius,
 	float mr, r;
 	float cos_theta, sin_theta, cos_phi, sin_phi;
 	float cos_3theta, sin_3theta;
-	float sin_phase, cos_phase, sin_2phase, cos_2phase;
+	float sin_phase, cos_phase;
+	/*float sin_2phase, cos_2phase;*/
 	float sin_3phase, cos_3phase;
 	float cos_dphi, sin_dphi, cos_dtheta, sin_dtheta, st, ct;
 	float offs;
@@ -837,8 +842,8 @@ calc_mesh_vertices(struct mesh *mesh, int density, float radius,
 	sin_phase = sin(phase);
 	cos_phase = cos(phase);
 
-	sin_2phase = 2.*sin_phase*cos_phase;
-	cos_2phase = 1. - 2.*sin_phase*sin_phase;
+	/*sin_2phase = 2.*sin_phase*cos_phase;
+	cos_2phase = 1. - 2.*sin_phase*sin_phase;*/
 
 	sin_3phase = 3.*sin_phase - 4.*sin_phase*sin_phase*sin_phase;
 	cos_3phase = 4.*cos_phase*cos_phase*cos_phase - 3.*cos_phase;
@@ -1091,7 +1096,7 @@ flare(unsigned char *dest)
 			a *= a; a *= a;
 			a *= a; a *= a;
 
-			r = a*255;
+			r = (int) (a*255);
 			s = (dest[i*TEXTURE_SIZE + j]>>1) + r;
 			s = s > 255 ? 255 : s;
 			dest[i*TEXTURE_SIZE + j] = s;
@@ -1349,7 +1354,7 @@ init_color_map(ModeInfo *mi, fzort_ctx *fz, float r, float g, float b,
 	XColor xc;
 
 	for (i = 0; i < 256; i++) {
-		ang = (255 - i)*(M_PI/2.)/256.;
+		ang = (255 - i)*(M_PI/2.)/256.0;
 
 		ka = kd * cos(ang);
 		kb = ks * pow(cos(ang), n);
@@ -1358,9 +1363,9 @@ init_color_map(ModeInfo *mi, fzort_ctx *fz, float r, float g, float b,
 		green = g*ka + kb;
 		blue = b*ka + kb;
 
-		ib = blue > 1. ? 255 : 255*blue;
-		ig = green > 1. ? 255 : 255*green;
-		ir = red > 1. ? 255 : 255*red;
+		ib = (unsigned int) ((blue > 1.0) ? 255 : 255*blue);
+		ig = (unsigned int) ((green > 1.0) ? 255 : 255*green);
+		ir = (unsigned int) ((red > 1.0) ? 255 : 255*red);
 
 		xc.red = ir<<8;
 		xc.green = ig<<8;
@@ -1488,7 +1493,7 @@ static void
 render(fzort_ctx *fz, long ticks)
 {
 	struct matrix t, v;
-	float a, b, c;
+	float a, b/* ,c*/;
 	struct matrix rmatrix, ry, rx;
 
 	a = (float)ticks/2000.;
@@ -1499,7 +1504,7 @@ render(fzort_ctx *fz, long ticks)
 	  /* 0., 0.); */
 
 	b = 1.5*a;
-	c = 2.2*a;
+	/*c = 2.2*a;*/
 
 	mat_make_rotation_around_y(&ry, 1.5*a);
 	mat_make_rotation_around_x(&rx, 2.2*a);
@@ -1537,7 +1542,6 @@ draw_fzort(ModeInfo *mi)
 {
 	fzort_ctx *fz;
 	int x0, y0, src_x_min, src_y_min, src_x_max, src_y_max;
-	int img_width, img_height;
 	int lines, bytes_per_pixel, bytes_per_block;
 	char *ptr;
 	long cur_ticks;
