@@ -87,8 +87,8 @@ static XrmOptionDescRec opts[] = {
 };
 
 static argtype vars[] = {
-  {(caddr_t *) &planetary, (char *) "planetary", (char *) "Planetary", (char *) DEF_PLANETARY, t_Bool},
-  {(caddr_t *) & planetsize, (char *) "planetsize", (char *) "PlanetSize", (char *) DEF_PLANETSIZE, t_Int}
+  {(void *) &planetary, (char *) "planetary", (char *) "Planetary", (char *) DEF_PLANETARY, t_Bool},
+  {(void *) & planetsize, (char *) "planetsize", (char *) "PlanetSize", (char *) DEF_PLANETSIZE, t_Int}
 };
 
 static OptionStruct desc[] = {
@@ -329,8 +329,8 @@ gear(GLfloat inner_radius, GLfloat outer_radius, GLfloat width,
 	}
 
 	if (!wire) {
-		glVertex3f(r1 * cos(0), r1 * sin(0), width * 0.5);
-		glVertex3f(r1 * cos(0), r1 * sin(0), -width * 0.5);
+		glVertex3f(r1, 0.0, width * 0.5);
+		glVertex3f(r1, 0.0, -width * 0.5);
 		glEnd();
 	}
 	if (!wire)
@@ -1190,13 +1190,13 @@ draw_gears(ModeInfo * mi)
 	int         angle_incr = MI_CYCLES(mi) ? MI_CYCLES(mi) : 2;
 	gearsstruct *gp;
 
-    if (gears == NULL)
-       return;
-    gp = &gears[MI_SCREEN(mi)];
+	if (gears == NULL)
+		return;
+	gp = &gears[MI_SCREEN(mi)];
 
-    MI_IS_DRAWN(mi) = True;
-    if (gp->planetary)
-      angle_incr *= 3;
+	MI_IS_DRAWN(mi) = True;
+	if (gp->planetary)
+		angle_incr *= 3;
 
 	if (!gp->glx_context)
 		return;
@@ -1209,11 +1209,11 @@ draw_gears(ModeInfo * mi)
 	/* let's do something so we don't get bored */
 	gp->angle = (int) (gp->angle + angle_incr) % 360;
 
-    rotate(&gp->rotx, &gp->dx, &gp->ddx, gp->d_max, MI_IS_VERBOSE(mi));
-    rotate(&gp->roty, &gp->dy, &gp->ddy, gp->d_max, MI_IS_VERBOSE(mi));
-    rotate(&gp->rotz, &gp->dz, &gp->ddz, gp->d_max, MI_IS_VERBOSE(mi));
+	rotate(&gp->rotx, &gp->dx, &gp->ddx, gp->d_max, MI_IS_VERBOSE(mi));
+	rotate(&gp->roty, &gp->dy, &gp->ddy, gp->d_max, MI_IS_VERBOSE(mi));
+	rotate(&gp->rotz, &gp->dz, &gp->ddz, gp->d_max, MI_IS_VERBOSE(mi));
 
-    if (MI_IS_FPS(mi)) do_fps (mi);
+	if (MI_IS_FPS(mi)) do_fps (mi);
 	glFinish();
 	glXSwapBuffers(display, window);
 }
