@@ -41,7 +41,7 @@ static const char sccsid[] = "@(#)glplanet.c	5.01 01/04/13 xlockmore";
  *
  * BUGS:
  * -bounce is broken
- * 
+ *
  *   For even more spectacular results, grab the images from the "SSysten"
  *   package (http://www.msu.edu/user/kamelkev/) and do this:
  *
@@ -110,7 +110,7 @@ static const char sccsid[] = "@(#)glplanet.c	5.01 01/04/13 xlockmore";
 # endif /* !VMS */
 #endif
 
-#include "sphere.h" 
+#include "sphere.h"
 
 #include <GL/glu.h>
 
@@ -151,19 +151,19 @@ static XrmOptionDescRec opts[] = {
 };
 
 static argtype vars[] = {
-  {(caddr_t *) &do_rotate,   (char *) "rotate",  (char *) "Rotate",
+  {(void *) &do_rotate,   (char *) "rotate",  (char *) "Rotate",
     (char *) DEF_ROTATE,  t_Bool},
-  {(caddr_t *) &do_roll,     (char *) "roll",    (char *) "Roll",
+  {(void *) &do_roll,     (char *) "roll",    (char *) "Roll",
     (char *) DEF_ROLL,    t_Bool},
-  {(caddr_t *) &do_bounce,   (char *) "bounce",  (char *) "Bounce",
+  {(void *) &do_bounce,   (char *) "bounce",  (char *) "Bounce",
     (char *) DEF_BOUNCE,  t_Bool},
-  {(caddr_t *) &do_texture,  (char *) "texture", (char *) "Texture",
+  {(void *) &do_texture,  (char *) "texture", (char *) "Texture",
     (char *) DEF_TEXTURE, t_Bool},
-  {(caddr_t *) &do_stars,    (char *) "stars",   (char *) "Stars",
+  {(void *) &do_stars,    (char *) "stars",   (char *) "Stars",
     (char *) DEF_STARS,   t_Bool},
-  {(caddr_t *) &do_light,    (char *) "light",   (char *) "Light",
+  {(void *) &do_light,    (char *) "light",   (char *) "Light",
     (char *) DEF_LIGHT,   t_Bool},
-  {(caddr_t *) &which_image, (char *) "pimage",  (char *) "Pimage",
+  {(void *) &which_image, (char *) "pimage",  (char *) "Pimage",
     (char *) DEF_IMAGE,   t_String},
 };
 
@@ -227,7 +227,7 @@ typedef struct {
   GLfloat dx, dy, dz;
   GLfloat box_width, box_height, box_depth;
   int roll_div, rot_div;
-  
+
 } planetstruct;
 
 
@@ -271,7 +271,7 @@ setup_xbm_texture (unsigned char *bits, int width, int height,
 	  {
 		unsigned char byte = bits [(y * (width / 8) + (x / 8))];
 		unsigned char bit = (byte & (1 << (x % 8))) >> (x % 8);
-		unsigned int word = (bit ? bg : fg); 
+		unsigned int word = (bit ? bg : fg);
 		*out++ = (word & 0xFF0000) >> 16;
 		*out++ = (word & 0x00FF00) >> 8;
 		*out++ = (word & 0x0000FF);
@@ -308,7 +308,7 @@ setup_file_texture (ModeInfo *mi, char *filename)
 #ifdef HAVE_XPM
   {
 	char **xpm_data = 0;
-	int result = XpmReadFileToData (filename, &xpm_data); 
+	int result = XpmReadFileToData (filename, &xpm_data);
 	switch (result) {
 	case XpmSuccess:
 	  {
@@ -334,7 +334,6 @@ setup_file_texture (ModeInfo *mi, char *filename)
 		glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
 		return True;
 	  }
-	  break;
 
 	case XpmOpenFailed:
 	  (void) fprintf (stderr, "Glplanet: file %s doesn't exist.\n", filename);
@@ -425,7 +424,7 @@ static void
 setup_face(void)
 {
   glEnable(GL_CULL_FACE);
-  glCullFace(GL_BACK); 
+  glCullFace(GL_BACK);
 }
 
 /* lame way to generate some random stars */
@@ -437,9 +436,9 @@ generate_stars(ModeInfo * mi, int width, int height)
   GLfloat x, y;
 
   planetstruct *gp = &planets[MI_SCREEN(mi)];
-  
+
 /*    glGetFloatv(GL_POINT_SIZE_RANGE, size_range); */
-  
+
 /*    (void) printf("size range: %f\t%f\n", size_range[0], size_range[1]); */
   gp->starlist = glGenLists(1);
   glNewList(gp->starlist, GL_COMPILE);
@@ -458,7 +457,7 @@ generate_stars(ModeInfo * mi, int width, int height)
   glEnable(GL_POINT_SMOOTH);
   glEnable(GL_BLEND);
   glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-  
+
   glBegin(GL_POINTS);
   for(i = 0 ; i < NUM_STARS ; i++)
 	{
@@ -494,7 +493,7 @@ pinit(ModeInfo * mi)
 
   /* turn on various options we like */
   if (do_texture) {
-	if (!setup_texture(mi)) 
+	if (!setup_texture(mi))
 		do_texture = False;
   }
   if (do_light)
@@ -528,7 +527,7 @@ draw_sphere_glp(ModeInfo * mi)
 	glEnable(GL_TEXTURE_2D);
 
   if (do_light)
-	{ 
+	{
 	  glEnable(GL_LIGHTING);
 	  glEnable(GL_LIGHT0);
 	  glColorMaterial(GL_FRONT, GL_AMBIENT_AND_DIFFUSE);
@@ -552,7 +551,7 @@ pick_velocity (ModeInfo * mi)
   if (gp->roll_div <= MINROLL) gp->roll_div = MINROLL * 10;
   gp->rot_div = MI_CYCLES(mi);
   if (gp->rot_div <= MINROT) gp->rot_div = MINROT * 50;
-  
+
   roll1 = gp->roll_div / 100.0;
   roll2 = roll1 * 0.75;
   rot1  = gp->rot_div  / 100.0;
@@ -573,7 +572,7 @@ pick_velocity (ModeInfo * mi)
 /* following values are unused
   gp->dx = (FLOATRAND(0.2) + FLOATRAND(0.2)) * RANDSIGN();
   gp->dy = (FLOATRAND(0.2) + FLOATRAND(0.2)) * RANDSIGN();
-  gp->dz = (FLOATRAND(0.2) + FLOATRAND(0.2)) * RANDSIGN(); */ 
+  gp->dz = (FLOATRAND(0.2) + FLOATRAND(0.2)) * RANDSIGN(); */
 }
 
 
@@ -613,7 +612,7 @@ rotate_and_move (ModeInfo * mi)
 */
 /* Original function replaced for faster execution */
 #     define SINOID(SCALE,SIZE) \
-        (sin(frame * (SCALE)) / 2.0) * (SIZE) 
+        (sin(frame * (SCALE)) / 2.0) * (SIZE)
       gp->xpos = SINOID(0.006086836, gp->box_width);
       gp->ypos = SINOID(0.004516039, gp->box_height);
       gp->zpos = SINOID(0.003337942, gp->box_depth);
@@ -693,7 +692,7 @@ init_glplanet(ModeInfo * mi)
 
 	free(f);
 	free(b);
-  } 
+  }
 
 
   gp->window = MI_WINDOW(mi);
