@@ -152,10 +152,10 @@ static XrmOptionDescRec opts[] =
 
 static argtype vars[] =
 {
-	{(caddr_t *) & sizex, (char *) "sizex", (char *) "SizeX", (char *) DEF_SIZEX, t_Int},
-	{(caddr_t *) & sizey, (char *) "sizey", (char *) "SizeY", (char *) DEF_SIZEY, t_Int},
-	{(caddr_t *) & sizez, (char *) "sizez", (char *) "SizeZ", (char *) DEF_SIZEZ, t_Int},
-	{(caddr_t *) & hideshuffling, (char *) "hideshuffling", (char *) "Hideshuffling", (char *) DEF_HIDESHUFFLING, t_Bool}
+	{(void *) & sizex, (char *) "sizex", (char *) "SizeX", (char *) DEF_SIZEX, t_Int},
+	{(void *) & sizey, (char *) "sizey", (char *) "SizeY", (char *) DEF_SIZEY, t_Int},
+	{(void *) & sizez, (char *) "sizez", (char *) "SizeZ", (char *) DEF_SIZEZ, t_Int},
+	{(void *) & hideshuffling, (char *) "hideshuffling", (char *) "Hideshuffling", (char *) DEF_HIDESHUFFLING, t_Bool}
 };
 
 static OptionStruct desc[] =
@@ -476,6 +476,7 @@ pickcolor(int C, int mono)
 				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialBlue);
 			break;
 #if 0
+		default:
 			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialCyan);
 			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialMagenta);
 #endif
@@ -1662,7 +1663,7 @@ slideRC(int face, int direction, int h, int sizeOnOppAxis,
 static Bool
 moveRubik(rubikstruct * rp, int face, int direction, int position)
 {
-	int         newFace, newDirection, rotate, reverse; 
+	int         newFace, newDirection, rotate, reverse;
 	int         h, k, newH;
 	int         i, j, sizeOfRow, sizeOfColumn, sizeOnAxis, sizeOnOppAxis;
 
@@ -1776,12 +1777,12 @@ moveRubik(rubikstruct * rp, int face, int direction, int position)
 			direction = newDirection;
 			h = newH;
 		}
-	}	
+	}
 	return True;
 }
 
 #ifdef DEBUG
-void
+static void
 printCube(rubikstruct * rp)
 {
 	int         face, position, sizeOfRow, sizeOfColumn;
