@@ -19,11 +19,11 @@ static const char sccsid[] = "@(#)sballs.c	5.02 2001/03/10 xlockmore";
  * event will the author be liable for any lost revenue or profits or
  * other special, indirect and consequential damages.
  *
- * The original code for this mode was written by 
+ * The original code for this mode was written by
  * Mustata Bogdan (LoneRunner) <lonerunner@planetquake.com>
  * and can be found at http://www.cfxweb.net/lonerunner/
  *
- * Eric Lassauge  (November-07-2000) <lassauge@mail.dotcom.fr>
+ * Eric Lassauge  (November-07-2000) <lassauge AT users.sourceforge.net>
  * 				    http://lassauge.free.fr/linux.html
  *
  * REVISION HISTORY:
@@ -104,9 +104,9 @@ static XrmOptionDescRec opts[] = {
 };
 
 static argtype vars[] = {
-    {(caddr_t *) & do_texture, (char *) "texture", (char *) "Texture", (char *) DEF_TEXTURE, t_Bool},
-    {(caddr_t *) & do_trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool},
-    {(caddr_t *) & object, (char *) "object", (char *) "Object", (char *) DEF_OBJECT, t_Int},
+    {(void *) & do_texture, (char *) "texture", (char *) "Texture", (char *) DEF_TEXTURE, t_Bool},
+    {(void *) & do_trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool},
+    {(void *) & object, (char *) "object", (char *) "Object", (char *) DEF_OBJECT, t_Int},
 
 };
 
@@ -313,7 +313,7 @@ static Polyinfo polygons[] =
 
         {
                 "pyramid", "pyramid",   /* long and short names */
-                5,			/* number of vertices */ 
+                5,			/* number of vertices */
 		0.5,
                 {               	/* vertices (x,y,z) */
                         /* all points must be within radius 1 of the origin */
@@ -398,7 +398,7 @@ static void trackmouse(ModeInfo * mi)
     if (fabs(center[0] - (float) cx) > 0.1 * (max[0] - min[0]))
 	sb->rot[0] -= ((center[0] - (float) cx) / (max[0] - min[0]) * 180.0f) / 200.0f;
     if (fabs(center[1] - (float) cy) > 0.1 * (max[1] - min[1]))
-        sb->rot[1] -= ((center[1] - (float) cy) / (max[1] - min[1]) * 180.0f) / 200.0f;;
+        sb->rot[1] -= ((center[1] - (float) cy) / (max[1] - min[1]) * 180.0f) / 200.0f;
     clamp(sb->rot);
 
     /* oops: can't get those buttons */
