@@ -459,7 +459,7 @@ static void
     case 14:
     case 15:
 	tp->phi += angle_speed;
-
+	break;
     case 16:
     case 17:
 	if (tp->camera_dist / FAC_CAMERA > tp->ref_camera_dist)
@@ -1169,7 +1169,7 @@ void
     if (!tp->glx_context)
 	return;
     tp->counter = tp->counter + 1;
-    if (tp->counter > MI_CYCLES(mi) & !nosplit)
+    if (tp->counter > (MI_CYCLES(mi) & !nosplit))
     {
 	int text_length = index_dir(tp->words, (char *) " ");
 
