@@ -134,14 +134,14 @@ static XrmOptionDescRec opts[] =
 
 static argtype vars[] =
 {
-	{(caddr_t *) & Disconnected, (char *) "disconnected", (char *) "Disconnected", (char *) DEF_DISCONNECTED, t_Bool},
-	{(caddr_t *) & Serial, (char *) "serial", (char *) "Serial", (char *) DEF_SERIAL, t_Bool},
-    {(caddr_t *) & Alternate, (char *) "alternate", (char *) "Alternate", (char *) DEF_ALTERNATE, t_Bool},
-    {(caddr_t *) & Spiral, (char *) "spiral", (char *) "Spiral", (char *) DEF_SPIRAL, t_Bool},
-    {(caddr_t *) & Spots, (char *) "spots", (char *) "Spots", (char *) DEF_SPOTS, t_Bool},
-	{(caddr_t *) & Quad, (char *) "quad", (char *) "Quad", (char *) DEF_QUAD, t_Bool},
-	{(caddr_t *) & Oct, (char *) "oct", (char *) "Oct", (char *) DEF_OCT, t_Bool},
-	{(caddr_t *) & Linear, (char *) "linear", (char *) "Linear", (char *) DEF_LINEAR, t_Bool}
+	{(void *) & Disconnected, (char *) "disconnected", (char *) "Disconnected", (char *) DEF_DISCONNECTED, t_Bool},
+	{(void *) & Serial, (char *) "serial", (char *) "Serial", (char *) DEF_SERIAL, t_Bool},
+	{(void *) & Alternate, (char *) "alternate", (char *) "Alternate", (char *) DEF_ALTERNATE, t_Bool},
+	{(void *) & Spiral, (char *) "spiral", (char *) "Spiral", (char *) DEF_SPIRAL, t_Bool},
+	{(void *) & Spots, (char *) "spots", (char *) "Spots", (char *) DEF_SPOTS, t_Bool},
+	{(void *) & Quad, (char *) "quad", (char *) "Quad", (char *) DEF_QUAD, t_Bool},
+	{(void *) & Oct, (char *) "oct", (char *) "Oct", (char *) DEF_OCT, t_Bool},
+	{(void *) & Linear, (char *) "linear", (char *) "Linear", (char *) DEF_LINEAR, t_Bool}
 };
 
 static OptionStruct desc[] =
@@ -862,7 +862,7 @@ GeneralLinearMoveAndBounce(
 				  kp->pen[pn].yv = PolarToCartY(rv, av);
 			  }
 		}
-    } else if (kp->spiral) {
+	} else if (kp->spiral) {
 	    if (*angle > 360.0) {
 	         kp->pen[pn].AngleOut = False;
 			 *angle = *angle - 360.0;
@@ -989,10 +989,10 @@ GeneralLinearMirrored(
 static void
 random_velocity(kaleidstruct * kp, int i)
 {
-    int tMxRV, tMnRV;
+	int tMxRV, tMnRV;
 	int tMxAV, tMnAV;
-    int tMxV,  tMnV;
-	
+	int tMxV,  tMnV;
+
 	if (kp->spots) {
 	    tMxRV = MaxRadialVelocity * SpotsMult;
 	    tMnRV = MinRadialVelocity * SpotsMult;
@@ -1336,7 +1336,7 @@ draw_kaleid(ModeInfo * mi)
 				OctMirrored(kp, i, segs);
 			}
 		} else {
-			if (kp->alternate) {	  
+			if (kp->alternate) {
 
 				if (kp->linear) {
 					GeneralLinearRotated(kp, i, segs);
@@ -1372,7 +1372,7 @@ draw_kaleid(ModeInfo * mi)
 			}
 		}
 	}
-	  
+
 
 	XSetLineAttributes(display, gc, 1, LineSolid, CapRound, JoinRound);
 	free(segs);
