@@ -499,9 +499,9 @@ walk(ModeInfo * mi, register int dir)
 			np->frames = (np->up < 0) ? R : RSTEP;
 		}
 		/* note that maybe neither UP nor DOWN is set! */
-		if (dir & UP && np->y > Y_INCR)
+		if ((dir & UP) && np->y > Y_INCR)
 			np->y -= Y_INCR;
-		else if (dir & DOWN && np->y < np->height - np->ys)
+		else if ((dir & DOWN) && np->y < np->height - np->ys)
 			np->y += Y_INCR;
 	} else if (dir == UP) {	/* Explicit up/down movement only (no left/right) */
 		np->y -= Y_INCR;
