@@ -348,25 +348,25 @@ static char nice_modes[][MAXMODECHARS] =
 	"kaleid",
 #endif
 #ifdef MODE_life
-  "life",
+	"life",
 #endif
 #ifdef MODE_life1d
-  "life1d",
+	"life1d",
 #endif
 #ifdef MODE_life3d
-  "life3d",
+	"life3d",
 #endif
 #ifdef MODE_lightning
-  "lightning",
+	"lightning",
 #endif
 #ifdef MODE_lisa
-  "lisa",
+	"lisa",
 #endif
 #ifdef MODE_lissie
-  "lissie",
+	"lissie",
 #endif
 #ifdef MODE_loop
-  "loop",
+	"loop",
 #endif
 #ifdef MODE_marquee
 	"marquee",
@@ -398,8 +398,8 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_roll
 	"roll",
 #endif
-#ifdef MODE_solitare
-	"solitare",
+#ifdef MODE_solitaire
+	"solitaire",
 #endif
 #ifdef MODE_space
 	"space",
@@ -486,8 +486,8 @@ static char mouse_modes[][MAXMODECHARS] =
 #ifdef MODE_pacman
 	"pacman",
 #endif
-#ifdef MODE_solitare
-	"solitare",
+#ifdef MODE_solitaire
+	"solitaire",
 #endif
 #ifdef MODE_tetris
 	"tetris",
@@ -942,6 +942,10 @@ parsemodelist(ModeInfo * mi)
 	}
 	return True;
 }
+#ifdef WIN32
+extern int showtext;/* from xlock.c */
+extern char* xlock95_get_modelist(void);/* from xlock95.c */
+#endif
 
 static void
 setMode(ModeInfo * mi, int newmode)
@@ -961,14 +965,30 @@ setMode(ModeInfo * mi, int newmode)
 	saturation = MI_SATURATION(mi) = LockProcs[currentmode].def_saturation;
 	bitmap = MI_BITMAP(mi) = LockProcs[currentmode].def_bitmap;
 
+#ifndef WIN32
 	for (i = startscreen; i < MI_NUM_SCREENS(mi); i++) {
 
 		XChangeGC(MI_DISPLAY(mi), MI_GC(mi), GC_SAVE_VALUES,
 			  &(rp->gcvs));		/* Not sure if this is right for multiscreens */
 		randoms[i].fix = True;
 	}
+#endif
 	if (MI_IS_VERBOSE(mi))
 		(void) fprintf(stderr, "mode %d: %s\n", currentmode, LockProcs[currentmode].cmdline_arg);
+#ifdef WIN32
+	{
+	  ModeSpecOpt *ms = LockProcs[currentmode].msopt;
+	  /*MI_COLORMAP_SIZE(mi) = ncolors = mi->screeninfo->npixels = colorcount;*/
+	  XFreeGC(MI_DISPLAY(mi), MI_GC(mi));
+	  MI_GC(mi) = GCCreate();
+	  xlockmore_set_mode_options(ms);
+
+	  /* Needed because WIN32 sections of xlock.c use these as
+		 globals */
+	  /*randommode = currentmode;
+	  showtext=0;*/
+	}
+#endif
 }
 
 void
@@ -983,7 +1003,10 @@ init_random(ModeInfo * mi)
 			return;
 	}
 	rp = &randoms[MI_SCREEN(mi)];
-
+#ifdef WIN32
+	/* Fetch current modelist from registry */
+	modelist = xlock95_get_modelist();
+#endif
 	MI_SET_FLAG_STATE(mi, WI_FLAG_FULLRANDOM, fullrandom);
 	if (currentmode < 0) {
 		if (!parsemodelist(mi))
