@@ -2,7 +2,7 @@
 /* wire --- logical circuits based on simple state-changes (wireworld) */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)wire.c	5.00 2000/11/01 xlockmore";
+static const char sccsid[] = "@(#)wire.c	5.24 2007/01/18 xlockmore";
 
 #endif
 
@@ -22,6 +22,7 @@ static const char sccsid[] = "@(#)wire.c	5.00 2000/11/01 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
+ * 18-Jan-2007: Added vertical option.
  * 01-Nov-2000: Allocation checks
  * 05-Dec-1997: neighbors option added.
  * 10-May-1997: Compatible with xscreensaver
@@ -109,22 +110,27 @@ static const char sccsid[] = "@(#)wire.c	5.00 2000/11/01 xlockmore";
  * neighbors of 0 randomizes it between 3, 4, 6, 8, 9, and 12.
  */
 #define DEF_NEIGHBORS  "0"      /* choose random value */
+#define DEF_VERTICAL "False"
 
 static int  neighbors;
+static Bool vertical;
 
 static XrmOptionDescRec opts[] =
 {
-	{(char *) "-neighbors", (char *) ".wire.neighbors", XrmoptionSepArg, (caddr_t) NULL}
+	{(char *) "-neighbors", (char *) ".wire.neighbors", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-vertical", (char *) ".wire.vertical", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+vertical", (char *) ".wire.vertical", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int
-}
+	{(void *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int},
+	{(void *) & vertical, (char *) "vertical", (char *) "Vertical", (char *) DEF_VERTICAL, t_Bool}
 };
 static OptionStruct desc[] =
 {
-	{(char *) "-neighbors num", (char *) "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"}
+	{(char *) "-neighbors num", (char *) "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"},
+	{(char *) "-/+vertical", (char *) "change orientation for hexagons and triangles"}
 };
 
 ModeSpecOpt wire_opts =
@@ -165,6 +171,7 @@ typedef struct _CellList {
 } CellList;
 
 typedef struct {
+	Bool        vertical;
 	int         init_bits;
 	int         neighbors;
 	int         generation;
@@ -200,38 +207,7 @@ position_of_neighbor(circuitstruct * wp, int dir, int *pcol, int *prow)
 
 	/* NO WRAPING */
 
-	if (wp->neighbors == 6) {
-		switch (dir) {
-			case 0:
-				col = col + 1;
-				break;
-			case 60:
-				if (!(row & 1))
-					col = col + 1;
-				row = row - 1;
-				break;
-			case 120:
-				if (row & 1)
-					col = col - 1;
-				row = row - 1;
-				break;
-			case 180:
-				col = col - 1;
-				break;
-			case 240:
-				if (row & 1)
-					col = col - 1;
-				row = row + 1;
-				break;
-			case 300:
-				if (!(row & 1))
-					col = col + 1;
-				row = row + 1;
-				break;
-			default:
-				(void) fprintf(stderr, "wrong direction %d\n", dir);
-		}
-	} else if (wp->neighbors == 4 || wp->neighbors == 8) {
+	if (wp->neighbors == 4 || wp->neighbors == 6 ||  wp->neighbors == 8) {
 		switch (dir) {
 			case 0:
 				col = col + 1;
@@ -240,9 +216,19 @@ position_of_neighbor(circuitstruct * wp, int dir, int *pcol, int *prow)
 				col = col + 1;
 				row = row - 1;
 				break;
+			case 60:
+				if (!(row & 1))
+					col = col + 1;
+				row = row - 1;
+				break;
 			case 90:
 				row = row - 1;
 				break;
+			case 120:
+				if (row & 1)
+					col = col - 1;
+				row = row - 1;
+				break;
 			case 135:
 				col = col - 1;
 				row = row - 1;
@@ -254,9 +240,19 @@ position_of_neighbor(circuitstruct * wp, int dir, int *pcol, int *prow)
 				col = col - 1;
 				row = row + 1;
 				break;
+			case 240:
+				if (row & 1)
+					col = col - 1;
+				row = row + 1;
+				break;
 			case 270:
 				row = row + 1;
 				break;
+			case 300:
+				if (!(row & 1))
+					col = col + 1;
+				row = row + 1;
+				break;
 			case 315:
 				col = col + 1;
 				row = row + 1;
@@ -392,34 +388,56 @@ fillcell(ModeInfo * mi, GC gc, int col, int row)
 	if (wp->neighbors == 6) {
 		int         ccol = 2 * col + !(row & 1), crow = 2 * row;
 
-		wp->shape.hexagon[0].x = wp->xb + ccol * wp->xs;
-		wp->shape.hexagon[0].y = wp->yb + crow * wp->ys;
+		if (wp->vertical) {
+			wp->shape.hexagon[0].x = wp->xb + ccol * wp->xs;
+			wp->shape.hexagon[0].y = wp->yb + crow * wp->ys;
+		} else {
+			wp->shape.hexagon[0].y = wp->xb + ccol * wp->xs;
+			wp->shape.hexagon[0].x = wp->yb + crow * wp->ys;
+		}
 		if (wp->xs <= 3 || wp->ys <= 3)
 			XDrawPoint(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
-			wp->shape.hexagon[0].x, wp->shape.hexagon[0].y);
+				wp->shape.hexagon[0].x,
+				wp->shape.hexagon[0].y);
 		else
 			XFillPolygon(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
-			    wp->shape.hexagon, 6, Convex, CoordModePrevious);
+				wp->shape.hexagon, 6,
+				Convex, CoordModePrevious);
 	} else if (wp->neighbors == 4 || wp->neighbors == 8) {
 		XFillRectangle(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
-		wp->xb + wp->xs * col, wp->yb + wp->ys * row,
-		wp->xs - (wp->xs > 3), wp->ys - (wp->ys > 3));
+			wp->xb + wp->xs * col, wp->yb + wp->ys * row,
+			wp->xs - (wp->xs > 3), wp->ys - (wp->ys > 3));
 	} else {		/* TRI */
-		int         orient = (col + row) % 2;	/* O left 1 right */
+		int orient = (col + row) % 2;	/* O left 1 right */
+		Bool small = (wp->xs <= 3 || wp->ys <= 3);
 
-		wp->shape.triangle[orient][0].x = wp->xb + col * wp->xs;
-		wp->shape.triangle[orient][0].y = wp->yb + row * wp->ys;
-		if (wp->xs <= 3 || wp->ys <= 3)
-			XDrawPoint(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
-			((orient) ? -1 : 1) + wp->shape.triangle[orient][0].x,
-				       wp->shape.triangle[orient][0].y);
-		else {
-			if (orient)
-				wp->shape.triangle[orient][0].x += (wp->xs / 2 - 1);
+		if (wp->vertical) {
+			wp->shape.triangle[orient][0].x = wp->xb + col * wp->xs;
+			wp->shape.triangle[orient][0].y = wp->yb + row * wp->ys;
+			if (small)
+				wp->shape.triangle[orient][0].x +=
+					((orient) ? -1 : 1);
 			else
-				wp->shape.triangle[orient][0].x -= (wp->xs / 2 - 1);
+				wp->shape.triangle[orient][0].x +=
+					(wp->xs / 2  - 1) * ((orient) ? 1 : -1);
+		} else {
+			wp->shape.triangle[orient][0].y = wp->xb + col * wp->xs;
+			wp->shape.triangle[orient][0].x = wp->yb + row * wp->ys;
+			if (small)	
+				wp->shape.triangle[orient][0].y +=
+					((orient) ? -1 : 1);
+			else
+				wp->shape.triangle[orient][0].y +=
+					(wp->xs / 2  - 1) * ((orient) ? 1 : -1);
+		}
+		if (small)
+			XDrawPoint(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+				wp->shape.triangle[orient][0].x,
+				wp->shape.triangle[orient][0].y);
+		else {
 			XFillPolygon(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
-				     wp->shape.triangle[orient], 3, Convex, CoordModePrevious);
+				wp->shape.triangle[orient], 3,
+				Convex, CoordModePrevious);
 		}
 	}
 }
@@ -548,14 +566,21 @@ draw_state(ModeInfo * mi, int state)
 			col = current->pt.x;
 			row = current->pt.y;
 			ccol = 2 * col + !(row & 1), crow = 2 * row;
-			wp->shape.hexagon[0].x = wp->xb + ccol * wp->xs;
-			wp->shape.hexagon[0].y = wp->yb + crow * wp->ys;
+			if (wp->vertical) {
+				wp->shape.hexagon[0].x = wp->xb + ccol * wp->xs;
+				wp->shape.hexagon[0].y = wp->yb + crow * wp->ys;
+			} else {
+				wp->shape.hexagon[0].y = wp->xb + ccol * wp->xs;
+				wp->shape.hexagon[0].x = wp->yb + crow * wp->ys;
+			}
 			if (wp->xs <= 1 || wp->ys <= 1)
-				XDrawPoint(MI_DISPLAY(mi), MI_WINDOW(mi),
-					       gc, wp->shape.hexagon[0].x, wp->shape.hexagon[0].y);
+				XDrawPoint(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+					wp->shape.hexagon[0].x,
+					wp->shape.hexagon[0].y);
 			else
 				XFillPolygon(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
-					     wp->shape.hexagon, 6, Convex, CoordModePrevious);
+					wp->shape.hexagon, 6,
+					Convex, CoordModePrevious);
 			current = current->next;
 		}
 	} else if (wp->neighbors == 4 || wp->neighbors == 8) {
@@ -583,24 +608,39 @@ draw_state(ModeInfo * mi, int state)
 		free(rects);
 	} else {		/* TRI */
 		while (current) {
-			int         col, row, orient;
+			int col, row, orient;
+			Bool small = (wp->xs <= 3 || wp->ys <= 3);
 
 			col = current->pt.x;
 			row = current->pt.y;
 			orient = (col + row) % 2;	/* O left 1 right */
-			wp->shape.triangle[orient][0].x = wp->xb + col * wp->xs;
-			wp->shape.triangle[orient][0].y = wp->yb + row * wp->ys;
-			if (wp->xs <= 3 || wp->ys <= 3)
-				XDrawPoint(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
-					       ((orient) ? -1 : 1) + wp->shape.triangle[orient][0].x,
-				      wp->shape.triangle[orient][0].y);
-			else {
-				if (orient)
-					wp->shape.triangle[orient][0].x += (wp->xs / 2 - 1);
+			if (wp->vertical) {
+				wp->shape.triangle[orient][0].x = wp->xb + col * wp->xs;
+				wp->shape.triangle[orient][0].y = wp->yb + row * wp->ys;
+				if (small)
+					wp->shape.triangle[orient][0].x +=
+						((orient) ? -1 : 1);
 				else
-					wp->shape.triangle[orient][0].x -= (wp->xs / 2 - 1);
+					wp->shape.triangle[orient][0].x +=
+						(wp->xs / 2  - 1) * ((orient) ? 1 : -1);
+			} else {
+				wp->shape.triangle[orient][0].y = wp->xb + col * wp->xs;
+				wp->shape.triangle[orient][0].x = wp->yb + row * wp->ys;
+				if (small)	
+					wp->shape.triangle[orient][0].y +=
+						((orient) ? -1 : 1);
+				else
+					wp->shape.triangle[orient][0].y +=
+						(wp->xs / 2  - 1) * ((orient) ? 1 : -1);
+			}
+			if (small)
+				XDrawPoint(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+					wp->shape.triangle[orient][0].x,
+					wp->shape.triangle[orient][0].y);
+			else {
 				XFillPolygon(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
-					     wp->shape.triangle[orient], 3, Convex, CoordModePrevious);
+					wp->shape.triangle[orient], 3,	
+					Convex, CoordModePrevious);
 			}
 			current = current->next;
 		}
@@ -817,6 +857,11 @@ init_wire(ModeInfo * mi)
 	}
 	free_list(wp);
 	wp->generation = 0;
+	if (MI_IS_FULLRANDOM(mi)) {
+		wp->vertical = (Bool) (LRAND() & 1);
+	} else {
+		wp->vertical = vertical;
+	}
 	wp->width = MI_WIDTH(mi);
 	wp->height = MI_HEIGHT(mi);
 
@@ -846,8 +891,12 @@ init_wire(ModeInfo * mi)
 	}
 
 	if (wp->neighbors == 6) {
-		int         nccols, ncrows;
+		int  nccols, ncrows;
 
+		if (!wp->vertical) {
+			wp->height = MI_WIDTH(mi);
+			wp->width = MI_HEIGHT(mi);
+		}
 		if (wp->width < 8)
 			wp->width = 8;
 		if (wp->height < 8)
@@ -872,8 +921,19 @@ init_wire(ModeInfo * mi)
 		wp->xb = (wp->width - wp->xs * nccols) / 2 + wp->xs;
 		wp->yb = (wp->height - wp->ys * ncrows) / 2 + wp->ys;
 		for (i = 0; i < 6; i++) {
-			wp->shape.hexagon[i].x = (wp->xs - 1) * hexagonUnit[i].x;
-			wp->shape.hexagon[i].y = ((wp->ys - 1) * hexagonUnit[i].y / 2) * 4 / 3;
+			if (wp->vertical) {
+				wp->shape.hexagon[i].x =
+					(wp->xs - 1) * hexagonUnit[i].x;
+				wp->shape.hexagon[i].y =
+					((wp->ys - 1) * hexagonUnit[i].y /
+					2) * 4 / 3;
+			} else {
+				wp->shape.hexagon[i].y =
+					(wp->xs - 1) * hexagonUnit[i].x;
+				wp->shape.hexagon[i].x =
+					((wp->ys - 1) * hexagonUnit[i].y /
+					2) * 4 / 3;
+			}
 		}
 	} else if (wp->neighbors == 4 || wp->neighbors == 8) {
 		if (size < -MINSIZE)
@@ -893,8 +953,12 @@ init_wire(ModeInfo * mi)
 		wp->xb = (wp->width - wp->xs * wp->ncols) / 2;
 		wp->yb = (wp->height - wp->ys * wp->nrows) / 2;
 	} else {		/* TRI */
-		int         orient;
+		int orient;
 
+		if (!wp->vertical) {
+			wp->height = MI_WIDTH(mi);
+			wp->width = MI_HEIGHT(mi);
+		}
 		if (wp->width < 4)
 			wp->width = 4;
 		if (wp->height < 2)
@@ -917,10 +981,17 @@ init_wire(ModeInfo * mi)
 		wp->yb = (wp->height - wp->ys * wp->nrows) / 2 + wp->ys;
 		for (orient = 0; orient < 2; orient++) {
 			for (i = 0; i < 3; i++) {
-				wp->shape.triangle[orient][i].x =
-					(wp->xs - 2) * triangleUnit[orient][i].x;
-				wp->shape.triangle[orient][i].y =
-					(wp->ys - 2) * triangleUnit[orient][i].y;
+				if (wp->vertical) {
+					wp->shape.triangle[orient][i].x =
+						(wp->xs - 2) * triangleUnit[orient][i].x;
+					wp->shape.triangle[orient][i].y =
+						(wp->ys - 2) * triangleUnit[orient][i].y;
+				} else {
+					wp->shape.triangle[orient][i].y =
+						(wp->xs - 2) * triangleUnit[orient][i].x;
+					wp->shape.triangle[orient][i].x =
+						(wp->ys - 2) * triangleUnit[orient][i].y;
+				}
 			}
 		}
 	}
