@@ -317,7 +317,7 @@ draw_xjack(ModeInfo * mi)
 			/* caps typo */
 			if (c >= 'a' && c <= 'z' && (jp->caps || !NRAND(350))) {
 				c -= ('a' - 'A');
-				if (c == 'O' && LRAND() & 1)
+				if (c == 'O' && (LRAND() & 1))
 					c = '0';
 			}
 
@@ -356,7 +356,7 @@ draw_xjack(ModeInfo * mi)
 		jp->s++;
 
 		if (!NRAND(200)) {
-			if (LRAND() & 1 && jp->s != source_message)
+			if ((LRAND() & 1) && jp->s != source_message)
 				jp->s--;   /* duplicate character */
 			else if (*(jp->s))
 				jp->s++;   /* skip character */
