@@ -17,7 +17,7 @@
  *         - Add handling of "similar to xmlock" RC file
  *         - etc...
  * Jul-98: Continual improvements by Remi Cohen-Scali <remi.cohenscali AT pobox.com>
- * ?? -98: First written by Charles Vidal <vidalc AT club-internet.fr>.
+ * ?? -98: First written by Charles Vidal <cvidal AT ivsweb.com>.
  */
 
 /*-
@@ -248,11 +248,11 @@ compose_xlock_command(gchar ***cmd_argv_p,
 
 #ifdef XGLOCK_DEBUG
 # define CHECK_REALLOC(num, size, need)                                                 \
-    fprintf(stderr,                                                                     \
+    (void) fprintf(stderr,                                                              \
             "check realloc: current=%ld need=%d size=%ld\n",                            \
             num, need, size );                                                          \
     if (size <= num+need) {                                                             \
-        fprintf(stderr,                                                                 \
+        (void)  fprintf(stderr,                                                         \
                 "must realloc: size <= num+need is %s\n",                               \
                 size<=num+need?"TRUE":"FALSE");                                         \
         cmd_argv =(char **)secured_realloc((gpointer)cmd_argv,                          \
@@ -322,7 +322,7 @@ compose_xlock_command(gchar ***cmd_argv_p,
                   if ( defflt == atoi( val ) )
                   {
 #ifdef XGLOCK_DEBUG
-                    fprintf(stderr,
+                    (void) fprintf(stderr,
                             "Option %s has its default value (%g): discarded\n",
                             generalOpt[i].cmdarg, defflt);
 #endif
@@ -332,7 +332,7 @@ compose_xlock_command(gchar ***cmd_argv_p,
                   if ( defval == atoi( val ) )
                   {
 #ifdef XGLOCK_DEBUG
-                    fprintf(stderr,
+                    (void) fprintf(stderr,
                             "Option %s has its default value (%d): discarded\n",
                             generalOpt[i].cmdarg, defval);
 #endif
@@ -377,8 +377,8 @@ compose_xlock_command(gchar ***cmd_argv_p,
                   (void) sprintf( cmd_argv[n], "-%s", fntcolorOpt[i].cmdarg );
                   n++;
 
-                  sscanf( val, "#%4hx%4hx%4hx (%lf)", &R, &G, &B, &T );
-                  sprintf( opt, "#%04x%04x%04x", R, G, B );
+                  (void) sscanf( val, "#%4hx%4hx%4hx (%lf)", &R, &G, &B, &T );
+                  (void) sprintf( opt, "#%04x%04x%04x", R, G, B );
 
                   cmd_argv[n] = (gchar*) secured_malloc( strlen( opt )+3 );
                   (void) sprintf( cmd_argv[n], "\"%s\"", opt );
@@ -499,9 +499,9 @@ launch_xlock(GtkWidget *w,
         compose_xlock_command( &cmd_argv, &args_size, &args_cnt );
 
 #ifdef XGLOCK_DEBUG
-        fprintf( stderr, "Running command: " );
+        (void) fprintf( stderr, "Running command: " );
         for ( i = 0; i < args_cnt; i++ )
-          fprintf( stderr, "%s ", cmd_argv[i] ? cmd_argv[i] : "\n" );
+          (void) fprintf( stderr, "%s ", cmd_argv[i] ? cmd_argv[i] : "\n" );
 #endif
         /* Allocate the launched pid_t dyntab */
         if ( !launchedprocesses )
@@ -520,7 +520,7 @@ launch_xlock(GtkWidget *w,
         if ( (launchedprocesses[num_launchedprocesses] = FORK() ) == -1 )
         {
             perror( FORK_STR );
-            fprintf(stderr,
+            (void) fprintf(stderr,
                     "Cannot " FORK_STR " process for xlock !\n" );
         }
         /* Child process */
@@ -598,7 +598,7 @@ bool_option_clicked_cb(GtkWidget *w,
 
     BoolOpt[optnr].value = !BoolOpt[optnr].value;
 #ifdef XGLOCK_DEBUG
-    fprintf(stderr,
+    (void) fprintf(stderr,
             "Option #%ud %s is %s\n",
             optnr, BoolOpt[optnr].cmdarg,
             BoolOpt[optnr].value ? "ACTIVE":"INACTIVE" );
@@ -655,14 +655,14 @@ mode_list_item_select_cb(GtkWidget *w,
             defflt = LockProcs[selected_mode].def_saturation; break;
         }
 	if (flt)
-        	sprintf(temp, "%g", defflt );
+        	(void) sprintf(temp, "%g", defflt );
 	else
-        	sprintf(temp, "%d", defval );
+        	(void) sprintf(temp, "%d", defval );
         gtk_entry_set_text(GTK_ENTRY(generalOpt[j].text_widget), temp);
     }
 
     if ( ( numberprocess = FORK() ) == -1 )
-      fprintf( stderr, "Fork error !\n" );
+      (void) fprintf( stderr, "Fork error !\n" );
     else if ( numberprocess == 0 ) {
         (void) execlp(XLOCK, XLOCK, "-parent", numberwidget,
                       MODE_STRING, LockProcs[mode].cmdline_arg, "-geometry", WINDOW_GEOMETRY, "-delay", "100000",
@@ -739,7 +739,7 @@ color_selection_ok_cb(GtkWidget *w,
     gtk_color_selection_set_current_color(colorsel, &gdkcol_bg);
     gtk_color_selection_get_current_alpha(colorsel);
 
-    sprintf(colorstr, "#%04x%04x%04x (%3.2f)",
+    (void) sprintf(colorstr, "#%04x%04x%04x (%3.2f)",
             gdkcol_bg.red,
             gdkcol_bg.green,
             gdkcol_bg.blue,
@@ -748,7 +748,7 @@ color_selection_ok_cb(GtkWidget *w,
     gtk_color_selection_get_color(colorsel, colors);
     gtk_color_selection_set_color(colorsel, colors);
 
-    sprintf(colorstr, "#%04x%04x%04x (%3.2f)",
+    (void) sprintf(colorstr, "#%04x%04x%04x (%3.2f)",
             (gushort)(colors[0] * 0xffff),
             (gushort)(colors[1] * 0xffff),
             (gushort)(colors[2] * 0xffff),
@@ -761,7 +761,7 @@ color_selection_ok_cb(GtkWidget *w,
     gdk_color_alloc(gdkcolormap, &gdkcol_bg);
 
 #ifdef XGLOCK_DEBUG
-    fprintf(stderr,
+    (void) fprintf(stderr,
             "Parsed bg color: color=#%04x%04x%04x pixel=%lx\n",
             gdkcol_bg.red,
             gdkcol_bg.green,
@@ -836,7 +836,7 @@ create_color_selection_dialog(GtkWidget *w,
     {
         gushort R, G, B;
 
-        sscanf( val, "#%04hx%04hx%04hx (%lf)", &R, &G, &B, &colors[3]);
+        (void) sscanf( val, "#%04hx%04hx%04hx (%lf)", &R, &G, &B, &colors[3]);
         gtk_color_selection_set_opacity(GTK_COLOR_SELECTION( GTK_COLOR_SELECTION_DIALOG(cbs_ptr->fntcol_dialog)->colorsel),
                                         colors[3] < 1.0);
 #if GTK_CHECK_VERSION(2,0,0)
@@ -1042,21 +1042,21 @@ static void
 contextual_help_dialog(GtkWidget *w,
                        gpointer udata )
 {
-    fprintf(stderr, "contextual_help_dialog !\n");
+    (void) fprintf(stderr, "contextual_help_dialog !\n");
 }
 
 static void
 window_help_dialog(GtkWidget *w,
                    gpointer udata )
 {
-    fprintf(stderr, "window_help_dialog !\n");
+    (void) fprintf(stderr, "window_help_dialog !\n");
 }
 
 static void
 global_help_dialog(GtkWidget *w,
                    gpointer udata )
 {
-    fprintf(stderr, "global_help_dialog !\n");
+    (void) fprintf(stderr, "global_help_dialog !\n");
 }
 
 static void about_dialog_close_callback(GtkWidget *widget, gpointer   data)
@@ -1141,7 +1141,7 @@ about_dialog(GtkWidget *w,
 
   xhbox = gtk_hbox_new(FALSE, 5);
   gtk_box_pack_start(GTK_BOX(xvbox), xhbox, TRUE, TRUE, 0);
-  text = "\nFirst written by Charles Vidal <vidalc@club-internet.fr>.\n"
+  text = "\nFirst written by Charles Vidal <cvidal@ivsweb.com>.\n"
 #if GTK_CHECK_VERSION(2,0,0)
          "Latest GTK+ 2.x by Éric Lassauge <lassauge@users.sourceforge.net>.\n\n"
 #else
@@ -1410,7 +1410,7 @@ create_fntColorOptions_entries(GtkScrolledWindow *window)
             break;
 
           default:
-            fprintf(stderr,
+            (void) fprintf(stderr,
                     "Program Inconsistency: Unknown parameter type #%d !\n",
                     fntcolorOpt[i].type );
         }
