@@ -88,14 +88,14 @@ hsb2rgb(double H, double S, double B,
  * Output is that many rgb triples which describe a linear
  * interpolate ramp between the two input colors.
  */
-#ifndef WIN32
-static void
-#else
+#ifdef WIN32
 /*-
  * make sure this function is NOT static under WIN32. We use it to
  * create the colortable in WIN32 specific stuff in xlock.c
  */
 void
+#else
+static void
 #endif
 hsbramp(double h1, double s1, double b1, double h2, double s2, double b2,
     int count, unsigned char *red, unsigned char *green, unsigned char *blue)
@@ -1185,3 +1185,229 @@ rgb_to_hsv(unsigned short r, unsigned short g, unsigned short b,
 	*v = V;
 }
 #endif
+
+
+static int
+allocate_color_planes (Display *dpy, Colormap cmap,
+		       int nplanes, unsigned long *plane_masks,
+		       unsigned long *base_pixel_ret)
+{
+  while (nplanes > 1 &&
+	 !XAllocColorCells (dpy, cmap, False, plane_masks, nplanes,
+			    base_pixel_ret, 1))
+    nplanes--;
+
+  return nplanes;
+}
+		       
+
+static void
+merge_colors (int argc, XColor **argv, XColor *into_color, int mask,
+	      Bool additive_p)
+{
+  int j;
+  *into_color = *argv [0];
+  into_color->pixel |= mask;
+
+  for (j = 1; j < argc; j++)
+    {
+# define SHORT_INC(x,y) (x = ((((x)+(y)) > 0xFFFF) ? 0xFFFF : ((x)+(y))))
+# define SHORT_DEC(x,y) (x = ((((x)-(y)) < 0)      ? 0      : ((x)-(y))))
+      if (additive_p)
+	{
+	  SHORT_INC (into_color->red,   argv[j]->red);
+	  SHORT_INC (into_color->green, argv[j]->green);
+	  SHORT_INC (into_color->blue,  argv[j]->blue);
+	}
+      else
+	{
+	  SHORT_DEC (into_color->red,   argv[j]->red);
+	  SHORT_DEC (into_color->green, argv[j]->green);
+	  SHORT_DEC (into_color->blue,  argv[j]->blue);
+	}
+# undef SHORT_INC
+# undef SHORT_DEC
+    }
+}
+
+static int 
+i_exp (int i, int j)
+{
+  int k = 1;
+  while (j--) k *= i;
+  return k;
+}
+
+
+
+static void
+permute_colors (XColor *pcolors, XColor *colors,
+		int count,
+		unsigned long *plane_masks,
+		Bool additive_p)
+{
+  int out = 0;
+  int max = i_exp (2, count);
+  if (count > 31) abort ();
+  for (out = 1; out < max; out++)
+    {
+      XColor *argv [32];
+      int this_mask = 0;
+      int argc = 0;
+      int bit;
+      for (bit = 0; bit < 32; bit++)
+	if (out & (1<<bit))
+	  {
+	    argv [argc++] = &pcolors [bit];
+	    this_mask |= plane_masks [bit];
+	  }
+      merge_colors (argc, argv, &colors [out-1], this_mask, additive_p);
+    }
+}
+
+
+static void
+initialize_transparency_colormap (Display *dpy, Colormap cmap,
+				  int nplanes,
+				  unsigned long base_pixel,
+				  unsigned long *plane_masks,
+				  XColor *colors,
+				  Bool additive_p , ModeInfo* mi )
+{
+  int i;
+  int total_colors = i_exp (2, nplanes);
+  XColor *all_colors = (XColor *) calloc (total_colors, sizeof (XColor));
+
+  for (i = 0; i < nplanes; i++)
+    colors[i].pixel = base_pixel | plane_masks [i];
+  permute_colors (colors, all_colors, nplanes, plane_masks, additive_p);
+
+  /* clone the default background of the window into our "base" pixel */
+  all_colors [total_colors - 1].pixel = MI_BLACK_PIXEL( mi );
+  XQueryColor (dpy, cmap, &all_colors [total_colors - 1]);
+  all_colors [total_colors - 1].pixel = base_pixel;
+
+  for (i = 0; i < total_colors; i++)
+    all_colors[i].flags = DoRed|DoGreen|DoBlue;
+  XStoreColors (dpy, cmap, all_colors, total_colors);
+  XFree ((XPointer) all_colors);
+}
+
+
+
+int
+screen_number (Screen *screen)
+{
+#ifndef WIN32
+  Display *dpy = DisplayOfScreen (screen);
+  int i;
+  for (i = 0; i < ScreenCount (dpy); i++)
+    if (ScreenOfDisplay (dpy, i) == screen)
+      return i;
+#endif
+  return 0;
+}
+
+
+int
+visual_depth (Screen *screen, Visual *visual)
+{
+#ifdef WIN32
+  return 8;
+#else
+  Display *dpy = DisplayOfScreen (screen);
+  XVisualInfo vi_in, *vi_out;
+  int out_count, d;
+  vi_in.screen = screen_number (screen);
+  vi_in.visualid = XVisualIDFromVisual (visual);
+  vi_out = XGetVisualInfo (dpy, VisualScreenMask|VisualIDMask,
+			   &vi_in, &out_count);
+  if (! vi_out) abort ();
+  d = vi_out [0].depth;
+  XFree ((char *) vi_out);
+  return d;
+#endif
+}
+
+
+Bool
+allocate_alpha_colors (Screen *screen, Visual *visual, Colormap cmap,
+		       int *nplanesP, Bool additive_p,
+		       unsigned long **plane_masks,
+		       unsigned long *base_pixelP , ModeInfo* mi)
+{
+#ifdef WIN32
+  return False;
+#else
+  Display *dpy = DisplayOfScreen (screen);
+  XColor *colors;
+  int nplanes = *nplanesP;
+  int i;
+
+  if (!has_writable_cells (mi))
+    cmap = 0;
+
+  if (!cmap)            /* A TrueColor visual, or similar. */
+    {
+      int depth = visual_depth (screen, visual);
+      unsigned long masks;
+      XVisualInfo vi_in, *vi_out;
+
+      /* Find out which bits the R, G, and B components actually occupy
+         on this visual. */
+      vi_in.screen = screen_number (screen);
+      vi_in.visualid = XVisualIDFromVisual (visual);
+      vi_out = XGetVisualInfo (dpy, VisualScreenMask|VisualIDMask,
+                               &vi_in, &i);
+      if (! vi_out) return False;
+      masks = vi_out[0].red_mask | vi_out[0].green_mask | vi_out[0].blue_mask;
+      XFree ((char *) vi_out);
+
+      if (nplanes > depth)
+        nplanes = depth;
+      *nplanesP = nplanes;
+      *base_pixelP = 0;
+      *plane_masks = (unsigned long *) calloc(sizeof(unsigned long), nplanes);
+
+      /* Pick the planar values randomly, but constrain them to fall within
+         the bit positions of the R, G, and B fields. */
+      for (i = 0; i < nplanes; i++)
+        (*plane_masks)[i] = LRAND() & masks;
+
+    }
+  else                  /* A PseudoColor visual, or similar. */
+    {
+      if (nplanes > 31) nplanes = 31;
+      *plane_masks = (unsigned long *) malloc(sizeof(unsigned long) * nplanes);
+
+      nplanes = allocate_color_planes (dpy, cmap, nplanes, *plane_masks,
+				   base_pixelP);
+      *nplanesP = nplanes;
+
+      if (nplanes <= 1)
+        {
+          free(*plane_masks);
+          *plane_masks = 0;
+          return False;
+        }
+
+      colors = (XColor *) calloc (nplanes, sizeof (XColor));
+      for (i = 0; i < nplanes; i++)
+        {
+          /* pick the base colors. If we are in subtractive mode, pick higher
+             intensities. */
+          hsv_to_rgb (NRAND( 360 ),
+                      NRAND( 100000 ) / 100000.0 ,
+                      NRAND( 100000 ) / 200000.0 + (additive_p ? 0.2 : 0.5),
+                      &colors[i].red,
+                      &colors[i].green,
+                      &colors[i].blue);
+        }
+      initialize_transparency_colormap (dpy, cmap, nplanes,
+                                        *base_pixelP, *plane_masks, colors,
+                                        additive_p , mi );
+      XFree ((XPointer) colors);
+    }
+  return True;
+#endif
+}
