@@ -277,11 +277,12 @@ sel_image(struct dirent *name)
 	}
 	name_tmp = name_tmp + ip;
 
-	if ( numfrag > 0 ) {
-		for (i = 1; i <= numfrag; ++i) {
+	if ( numfrag > 0 )
+		for (i = 1; i <= numfrag; ++i)
 #else
-		for (i = 0; i <= numfrag; ++i) {
+		for (i = 0; i <= numfrag; ++i)
 #endif
+		{
 			ip = index_dir(name_tmp, frags[i]);
 			free(frags[i]);
 			if (ip == 0) {
@@ -289,9 +290,6 @@ sel_image(struct dirent *name)
 			}
 			name_tmp = name_tmp + ip;
 		}
-#ifdef VMS
-	}
-#endif
 
 	return (1);
 FAIL:
