@@ -644,11 +644,11 @@ LockStruct  LockProcs[] =
 	 50000, 35, 50, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows slipping blits", 0, NULL},
 #endif
-#ifdef MODE_solitare
-	{(char *) "solitare", init_solitare, draw_solitare, release_solitare,
-	 refresh_solitare, init_solitare, (ModeHook *) NULL, &solitare_opts,
+#ifdef MODE_solitaire
+	{(char *) "solitaire", init_solitaire, draw_solitaire, release_solitaire,
+	 refresh_solitaire, init_solitaire, (ModeHook *) NULL, &solitaire_opts,
 	 2000000, 1, 1, 1, 64, 1.0, (char *) "",
-	 (char *) "Shows Klondike's game of solitare", 0, NULL},
+	 (char *) "Shows Klondike's game of solitaire", 0, NULL},
 #endif
 #ifdef MODE_space
 	{(char *) "space", init_space, draw_space, release_space,
