@@ -528,7 +528,7 @@ extern void release_last_mode(ModeInfo *);
 #endif	/* HAVE_CXX */
 #endif	/* USE_GL */
 #ifdef HAVE_CXX
-#define MODE_solitare
+#define MODE_solitaire
 #endif
 #ifdef USE_UNSTABLE
 #define MODE_run /* VMS problems as well as -debug problems */
@@ -682,7 +682,7 @@ extern void release_last_mode(ModeInfo *);
 
 #else /* NICE_ONLY */
 #ifdef HAVE_CXX
-#define MODE_solitare
+#define MODE_solitaire
 #endif
 #define MODE_apollonian
 #define MODE_blot
@@ -1577,12 +1577,12 @@ extern ModeHook refresh_slip;	/* Probably not practical */
 extern ModeSpecOpt slip_opts;
 #endif
 
-#ifdef MODE_solitare
-extern ModeHook init_solitare;
-extern ModeHook draw_solitare;
-extern ModeHook release_solitare;
-extern ModeHook refresh_solitare;
-extern ModeSpecOpt solitare_opts;
+#ifdef MODE_solitaire
+extern ModeHook init_solitaire;
+extern ModeHook draw_solitaire;
+extern ModeHook release_solitaire;
+extern ModeHook refresh_solitaire;
+extern ModeSpecOpt solitaire_opts;
 #endif
 
 #ifdef MODE_space
