@@ -1239,11 +1239,11 @@ checkPasswd(char *buffer)
 	(void) setregid(rgid, egid);
 #endif
 #endif
-	done = ((authenticate_user((struct passwd *) getpwnam(user),
+	done = (authenticate_user((struct passwd *) getpwnam(user),
 		buffer, NULL) >= 0);
 	if (!done && allowroot &&
 			(authenticate_user((struct passwd *) getpwnam(ROOT),
-			buffer, NULL) >= 0))) {
+			buffer, NULL) >= 0)) {
 		done = True;
 		if (!*buffer)
 			/*
@@ -1398,11 +1398,11 @@ checkPasswd(char *buffer)
 	(void) printf("buffer=%s, encrypt=%s, userpass=%s,\n", buffer,
 		      (char *) crypt(buffer, userpass), userpass);
 #endif
-	if (!done && allowroot &&
+	if (!done && allowroot
 #ifdef OSF1_ENH_SEC
-		!strcmp((char *) dispcrypt(buffer, rootpass, root_oldcrypt), rootpass)
+		&& !strcmp((char *) dispcrypt(buffer, rootpass, root_oldcrypt), rootpass)
 #else
-		!strcmp((char *) crypt(buffer, rootpass), rootpass)
+		&& !strcmp((char *) crypt(buffer, rootpass), rootpass)
 #endif
 	) {
 		done = True;
@@ -1481,6 +1481,7 @@ initDCE(void)
 					(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
 					ProgramName : DEFAULT_NAME);
 				error(error_buf);
+				/* NOTREACHED */
 			default:
 				(void) fprintf(stderr,
 					       "%s: sec_login_setup_identity() returned status %d\n",
@@ -1528,6 +1529,7 @@ initDCE(void)
 						(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
 						ProgramName : DEFAULT_NAME);
 					error(error_buf);
+					/* NOTREACHED */
 				default:
 					(void) fprintf(stderr,
 					       "%s: sec_login_setup_identity() returned status %d\n",
@@ -1721,13 +1723,14 @@ krb_check_password(struct passwd *pwd, char *pass)
 	char        tkfile[MAXPATHLEN];
 
 	/* find local realm */
-	if (krb_get_lrealm(realm, 1) != KSUCCESS)
+	if (krb_get_lrealm(realm, 1) != KSUCCESS) {
 #ifdef KRB_REALM
 		/* krb_get_default_realm() may not work well on Solaris */
 		(void) strncpy(realm, KRB_REALM, sizeof (realm));
 #else
 		(void) strncpy(realm, krb_get_default_realm(), sizeof (realm));
 #endif
+	}
 	/* Construct a ticket file */
 	(void) sprintf(tkfile, "/tmp/tkt_%d", pwd->pw_uid);
 
@@ -1954,7 +1957,7 @@ set_multiple(int uid)
 		}
 	}
 
-	if (pwll->next = new_pwlnode())
+	if ((pwll->next = new_pwlnode()) != NULL)
 		pwll = pwll->next;
 #else /* !BSD_AUTH */
 	/* If you thought the above was sick, then you will think this is
