@@ -180,6 +180,8 @@ static int  descr();
 #include "resource-msg-nl.h"
 #elif defined JA
 #include "resource-msg-ja.h"
+#elif defined ZH
+#include "resource-msg-zh_TW.h"
 #else
 #include "resource-msg-en.h"
 #endif
@@ -366,6 +368,8 @@ static XrmOptionDescRec genTable[] =
 	{(char *) "+mousemotion", (char *) ".mousemotion", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-sound", (char *) ".sound", XrmoptionNoArg, (caddr_t) "on"},
 	{(char *) "+sound", (char *) ".sound", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-showdate", (char *) ".showdate", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+showdate", (char *) ".showdate", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-timeelapsed", (char *) ".timeelapsed", XrmoptionNoArg, (caddr_t) "on"},
 	{(char *) "+timeelapsed", (char *) ".timeelapsed", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-usefirst", (char *) ".usefirst", XrmoptionNoArg, (caddr_t) "on"},
@@ -592,6 +596,7 @@ static OptionStruct opDesc[] =
 	{(char *) "-/+hide", (char *) "turn on/off user background manipulation"},
 	{(char *) "-/+mousemotion", (char *) "turn on/off sensitivity to mouse"},
 	{(char *) "-/+sound", (char *) "whether to use sound if configured for it (yes/no)"},
+	{(char *) "-/+showdate", (char *) "turn on/off date in password window"},
 	{(char *) "-/+timeelapsed", (char *) "turn on/off clock"},
 	{(char *) "-/+usefirst", (char *) "turn on/off using the first char typed in password"},
 	{(char *) "-/+verbose", (char *) "turn on/off verbosity"},
@@ -730,6 +735,7 @@ Bool        hide;
 Bool        install;
 Bool        mousemotion;
 Bool        sound;
+Bool        showdate;
 Bool        timeelapsed;
 Bool        usefirst;
 Bool        verbose;
@@ -878,6 +884,7 @@ static argtype genvars[] =
 	{(void *) & fpsTop, (char *) "fpstop", (char *) "FpsTop", (char *) "on", t_Bool},
 	{(void *) & fpsfontname, (char *) "fpsfont", (char *) "FpsFont", (char *) DEF_FONT, t_String},
 #endif
+	{(void *) & showdate, (char *) "showdate", (char *) "ShowDate", (char *) "on", t_Bool},
 	{(void *) & timeelapsed, (char *) "timeelapsed", (char *) "TimeElapsed", (char *) "off", t_Bool},
 	{(void *) & usefirst, (char *) "usefirst", (char *) "UseFirst", (char *) "on", t_Bool},
 	{(void *) & verbose, (char *) "verbose", (char *) "Verbose", (char *) "off", t_Bool},
