@@ -1,5 +1,5 @@
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)visgl.c	5.01 01/02/19 xlockmore";
+static const char sccsid[] = "@(#)visgl.c	5.24 2007/01/18 xlockmore";
 
 #endif
 
@@ -141,6 +141,10 @@ init_GL(ModeInfo * mi)
 			xc[i].blue = (i << bits0) | i;
 			xc[i].flags = DoRed | DoGreen | DoBlue;
 		}
+#ifdef DIRECTCOLOR_FIX
+	MI_BLACK_PIXEL(mi) = xc[0].pixel;
+	MI_WHITE_PIXEL(mi) = xc[maxColors - 1].pixel;
+#else
 #ifndef NO_RESERVE_BLACK
 		i = 0;
 		xc[i].pixel = MI_BLACK_PIXEL(mi);
@@ -155,6 +159,7 @@ init_GL(ModeInfo * mi)
 		xc[i].red = 0xFFFF;
 		xc[i].green = 0xFFFF;
 		xc[i].blue = 0xFFFF;
+#endif
 #endif
 		XStoreColors(display, cmap, xc, maxColors);
 		XInstallColormap(display, cmap);
